from dingtalk.api.rest.CcoserviceServicegroupGetRequest import CcoserviceServicegroupGetRequest
from dingtalk.api.rest.CorpHrmEmployeeSetuserworkdataRequest import CorpHrmEmployeeSetuserworkdataRequest
from dingtalk.api.rest.OapiSnsConversationInfoRequest import OapiSnsConversationInfoRequest
from dingtalk.api.rest.OapiProcessWorkrecordCreateRequest import OapiProcessWorkrecordCreateRequest
from dingtalk.api.rest.OapiDingpayVirtualaccountQueryRequest import OapiDingpayVirtualaccountQueryRequest
from dingtalk.api.rest.OapiMaterialArticleListRequest import OapiMaterialArticleListRequest
from dingtalk.api.rest.OapiSmartdeviceFaceFeatureRequest import OapiSmartdeviceFaceFeatureRequest
from dingtalk.api.rest.OapiV2DepartmentDeleteRequest import OapiV2DepartmentDeleteRequest
from dingtalk.api.rest.OapiEduSubjectCreateRequest import OapiEduSubjectCreateRequest
from dingtalk.api.rest.OapiDingpayRedenvelopeSendRequest import OapiDingpayRedenvelopeSendRequest
from dingtalk.api.rest.OapiAttendanceGetsimplegroupsRequest import OapiAttendanceGetsimplegroupsRequest
from dingtalk.api.rest.OapiCollectionFormDeleteRequest import OapiCollectionFormDeleteRequest
from dingtalk.api.rest.OapiInspectFeedbackGetRequest import OapiInspectFeedbackGetRequest
from dingtalk.api.rest.OapiUserCreateRequest import OapiUserCreateRequest
from dingtalk.api.rest.CorpRoleListRequest import CorpRoleListRequest
from dingtalk.api.rest.OapiAsrVoiceTranslateRequest import OapiAsrVoiceTranslateRequest
from dingtalk.api.rest.OapiAlitripBtripReimbursementGetRequest import OapiAlitripBtripReimbursementGetRequest
from dingtalk.api.rest.OapiEduCardUserPostUpdateRequest import OapiEduCardUserPostUpdateRequest
from dingtalk.api.rest.OapiSceneservicegroupGroupCreateRequest import OapiSceneservicegroupGroupCreateRequest
from dingtalk.api.rest.OapiV2SafeSetenableRequest import OapiV2SafeSetenableRequest
from dingtalk.api.rest.OapiRhinoOpenserviceQueryRequest import OapiRhinoOpenserviceQueryRequest
from dingtalk.api.rest.CorpExtAddRequest import CorpExtAddRequest
from dingtalk.api.rest.OapiRobotMessageStatisticsListRequest import OapiRobotMessageStatisticsListRequest
from dingtalk.api.rest.OapiAttendanceCorpInviteactiveOpenRequest import OapiAttendanceCorpInviteactiveOpenRequest
from dingtalk.api.rest.OapiFinanceLoanNotifyRepaymentRequest import OapiFinanceLoanNotifyRepaymentRequest
from dingtalk.api.rest.OapiEduStudentListRequest import OapiEduStudentListRequest
from dingtalk.api.rest.CorpMessageCorpconversationSendmockRequest import CorpMessageCorpconversationSendmockRequest
from dingtalk.api.rest.OapiImChatServicegroupMemberQueryRequest import OapiImChatServicegroupMemberQueryRequest
from dingtalk.api.rest.OapiServiceaccountGetRequest import OapiServiceaccountGetRequest
from dingtalk.api.rest.OapiWorkspaceTasklistHidebyorgRequest import OapiWorkspaceTasklistHidebyorgRequest
from dingtalk.api.rest.OapiAttendanceGroupQueryRequest import OapiAttendanceGroupQueryRequest
from dingtalk.api.rest.OapiIndustryDepartmentListRequest import OapiIndustryDepartmentListRequest
from dingtalk.api.rest.CorpSmartdeviceAddfaceRequest import CorpSmartdeviceAddfaceRequest
from dingtalk.api.rest.OapiSmartdeviceQrQueryRequest import OapiSmartdeviceQrQueryRequest
from dingtalk.api.rest.OapiMicroappVisibleScopesRequest import OapiMicroappVisibleScopesRequest
from dingtalk.api.rest.OapiProcessPrintTemplateSaveRequest import OapiProcessPrintTemplateSaveRequest
from dingtalk.api.rest.OapiRhinoOrderDetailGetRequest import OapiRhinoOrderDetailGetRequest
from dingtalk.api.rest.OapiWorkrecordUpdateRequest import OapiWorkrecordUpdateRequest
from dingtalk.api.rest.OapiAttendanceGroupUsersQueryRequest import OapiAttendanceGroupUsersQueryRequest
from dingtalk.api.rest.OapiInspectTaskListRequest import OapiInspectTaskListRequest
from dingtalk.api.rest.OapiServiceGetUnactiveCorpRequest import OapiServiceGetUnactiveCorpRequest
from dingtalk.api.rest.OapiReportReceiverListRequest import OapiReportReceiverListRequest
from dingtalk.api.rest.OapiEduGradeQueryRequest import OapiEduGradeQueryRequest
from dingtalk.api.rest.OapiDdpaasObjectdataQueryRequest import OapiDdpaasObjectdataQueryRequest
from dingtalk.api.rest.OapiSnsGetuserinfoBycodeRequest import OapiSnsGetuserinfoBycodeRequest
from dingtalk.api.rest.OapiContactRolevisibilityGetRequest import OapiContactRolevisibilityGetRequest
from dingtalk.api.rest.OapiAttendanceGroupSearchRequest import OapiAttendanceGroupSearchRequest
from dingtalk.api.rest.OapiKacDatavAnnualReportGetRequest import OapiKacDatavAnnualReportGetRequest
from dingtalk.api.rest.OapiEduCardUserTaskSubmitRequest import OapiEduCardUserTaskSubmitRequest
from dingtalk.api.rest.OapiMessageCorpconversationGetsendprogressRequest import OapiMessageCorpconversationGetsendprogressRequest
from dingtalk.api.rest.OapiDingTaskCreateRequest import OapiDingTaskCreateRequest
from dingtalk.api.rest.OapiAttendanceApproveScheduleSwitchRequest import OapiAttendanceApproveScheduleSwitchRequest
from dingtalk.api.rest.OapiEduUserAuthGetRequest import OapiEduUserAuthGetRequest
from dingtalk.api.rest.CorpExtcontactDeleteRequest import CorpExtcontactDeleteRequest
from dingtalk.api.rest.OapiRobotMessageOtotaskQueryRequest import OapiRobotMessageOtotaskQueryRequest
from dingtalk.api.rest.OapiWorkrecordGetbyuseridRequest import OapiWorkrecordGetbyuseridRequest
from dingtalk.api.rest.OapiEduUserClassrolesGetRequest import OapiEduUserClassrolesGetRequest
from dingtalk.api.rest.OapiMicroappCustomUpdateRequest import OapiMicroappCustomUpdateRequest
from dingtalk.api.rest.OapiProjectPointHistoryPageRequest import OapiProjectPointHistoryPageRequest
from dingtalk.api.rest.OapiOrgOpenencryptRegistekmsRequest import OapiOrgOpenencryptRegistekmsRequest
from dingtalk.api.rest.OapiProcessPrinterTemplateDeleteRequest import OapiProcessPrinterTemplateDeleteRequest
from dingtalk.api.rest.OapiServiceActivateSuiteRequest import OapiServiceActivateSuiteRequest
from dingtalk.api.rest.OapiPlanetomFeedsInteractivedataGetRequest import OapiPlanetomFeedsInteractivedataGetRequest
from dingtalk.api.rest.OapiProcessCleanRequest import OapiProcessCleanRequest
from dingtalk.api.rest.OapiEduCourseParticipantRemoveRequest import OapiEduCourseParticipantRemoveRequest
from dingtalk.api.rest.OapiMicroappListRequest import OapiMicroappListRequest
from dingtalk.api.rest.OapiDingpayOrderMarkotherpayRequest import OapiDingpayOrderMarkotherpayRequest
from dingtalk.api.rest.OapiCustomerserviceSessionCreateRequest import OapiCustomerserviceSessionCreateRequest
from dingtalk.api.rest.CorpExtcontactGetRequest import CorpExtcontactGetRequest
from dingtalk.api.rest.OapiSnsVerifyMobileRequest import OapiSnsVerifyMobileRequest
from dingtalk.api.rest.OapiAttendanceGetAttendUpdateDataRequest import OapiAttendanceGetAttendUpdateDataRequest
from dingtalk.api.rest.OapiMicroappScopeDeleteRequest import OapiMicroappScopeDeleteRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeV2UpdateRequest import OapiSmartworkHrmEmployeeV2UpdateRequest
from dingtalk.api.rest.OapiImChatScencegroupRobotQueryRequest import OapiImChatScencegroupRobotQueryRequest
from dingtalk.api.rest.OapiExtcontactListRequest import OapiExtcontactListRequest
from dingtalk.api.rest.OapiCalendarV2EventUpdateRequest import OapiCalendarV2EventUpdateRequest
from dingtalk.api.rest.CorpInvoiceGettitleRequest import CorpInvoiceGettitleRequest
from dingtalk.api.rest.OapiMpdevPreviewbuildCreateRequest import OapiMpdevPreviewbuildCreateRequest
from dingtalk.api.rest.OapiUserGetByMobileRequest import OapiUserGetByMobileRequest
from dingtalk.api.rest.OapiAlitripBtripTrainCitySuggestRequest import OapiAlitripBtripTrainCitySuggestRequest
from dingtalk.api.rest.OapiSmartworkHrmFlexibleApplytokenRequest import OapiSmartworkHrmFlexibleApplytokenRequest
from dingtalk.api.rest.OapiImChatScencegroupMessageQueryRequest import OapiImChatScencegroupMessageQueryRequest
from dingtalk.api.rest.OapiSmartdeviceDevicememberListRequest import OapiSmartdeviceDevicememberListRequest
from dingtalk.api.rest.OapiPbpEventDeleteRequest import OapiPbpEventDeleteRequest
from dingtalk.api.rest.OapiProjectInviteShareurlGetRequest import OapiProjectInviteShareurlGetRequest
from dingtalk.api.rest.CorpExtListlabelgroupsRequest import CorpExtListlabelgroupsRequest
from dingtalk.api.rest.OapiProcessDirlistGetRequest import OapiProcessDirlistGetRequest
from dingtalk.api.rest.OapiEduTextbookMetadataListRequest import OapiEduTextbookMetadataListRequest
from dingtalk.api.rest.OapiProcessGettodonumRequest import OapiProcessGettodonumRequest
from dingtalk.api.rest.OapiCertifyQueryinfoRequest import OapiCertifyQueryinfoRequest
from dingtalk.api.rest.OapiRetailUserUnbindRequest import OapiRetailUserUnbindRequest
from dingtalk.api.rest.OapiChatGetCidRequest import OapiChatGetCidRequest
from dingtalk.api.rest.OapiWorkspaceTaskGetRequest import OapiWorkspaceTaskGetRequest
from dingtalk.api.rest.OapiSmartdeviceDeviceQuerybyidRequest import OapiSmartdeviceDeviceQuerybyidRequest
from dingtalk.api.rest.OapiV2SafeSetdisableRequest import OapiV2SafeSetdisableRequest
from dingtalk.api.rest.OapiSmartdeviceDevicememberRemoveallRequest import OapiSmartdeviceDevicememberRemoveallRequest
from dingtalk.api.rest.OapiReportTemplateListbyuseridRequest import OapiReportTemplateListbyuseridRequest
from dingtalk.api.rest.OapiImChatScenegroupCreateRequest import OapiImChatScenegroupCreateRequest
from dingtalk.api.rest.OapiLiveGroupliveStatisticsRequest import OapiLiveGroupliveStatisticsRequest
from dingtalk.api.rest.OapiCheckinRecordRequest import OapiCheckinRecordRequest
from dingtalk.api.rest.CorpBlazersUnbindRequest import CorpBlazersUnbindRequest
from dingtalk.api.rest.CorpCalendarCreateRequest import CorpCalendarCreateRequest
from dingtalk.api.rest.OapiAttendanceGetupdatedataRequest import OapiAttendanceGetupdatedataRequest
from dingtalk.api.rest.OapiMessageCorpconversationSendbytemplateRequest import OapiMessageCorpconversationSendbytemplateRequest
from dingtalk.api.rest.OapiEduClassStudentidGetRequest import OapiEduClassStudentidGetRequest
from dingtalk.api.rest.OapiChatGetRequest import OapiChatGetRequest
from dingtalk.api.rest.OapiUserGetuserinfoRequest import OapiUserGetuserinfoRequest
from dingtalk.api.rest.OapiDingmiCommonRobotAskRequest import OapiDingmiCommonRobotAskRequest
from dingtalk.api.rest.CorpDeviceManageHasbinddeviceRequest import CorpDeviceManageHasbinddeviceRequest
from dingtalk.api.rest.OapiSmartdeviceFocusdetailGetRequest import OapiSmartdeviceFocusdetailGetRequest
from dingtalk.api.rest.OapiEduHomeworkStudentCommentCreateRequest import OapiEduHomeworkStudentCommentCreateRequest
from dingtalk.api.rest.OapiAppstoreInternalOrderGetRequest import OapiAppstoreInternalOrderGetRequest
from dingtalk.api.rest.OapiAlitripBtripReimbursementInitRequest import OapiAlitripBtripReimbursementInitRequest
from dingtalk.api.rest.OapiOpenencryptRotateedkRequest import OapiOpenencryptRotateedkRequest
from dingtalk.api.rest.OapiPlatformTranslateRequest import OapiPlatformTranslateRequest
from dingtalk.api.rest.OapiEduGradeCreateRequest import OapiEduGradeCreateRequest
from dingtalk.api.rest.CorpBlazersGetbizidRequest import CorpBlazersGetbizidRequest
from dingtalk.api.rest.OapiAttendanceGetleavetimebynamesRequest import OapiAttendanceGetleavetimebynamesRequest
from dingtalk.api.rest.OapiChatSendRequest import OapiChatSendRequest
from dingtalk.api.rest.OapiDingpayRedenvelopeGetRequest import OapiDingpayRedenvelopeGetRequest
from dingtalk.api.rest.OapiMicroappListbypageRequest import OapiMicroappListbypageRequest
from dingtalk.api.rest.OapiDingtalkImpaasMessageCrossdomainReadRequest import OapiDingtalkImpaasMessageCrossdomainReadRequest
from dingtalk.api.rest.OapiSsoGetuserinfoRequest import OapiSsoGetuserinfoRequest
from dingtalk.api.rest.OapiHireJobQueryjobidsRequest import OapiHireJobQueryjobidsRequest
from dingtalk.api.rest.OapiAttendanceTokenGetRequest import OapiAttendanceTokenGetRequest
from dingtalk.api.rest.OapiUserDeleteRequest import OapiUserDeleteRequest
from dingtalk.api.rest.OapiImpaasConversationOpencidGetRequest import OapiImpaasConversationOpencidGetRequest
from dingtalk.api.rest.SmartworkBpmsProcessinstanceGetRequest import SmartworkBpmsProcessinstanceGetRequest
from dingtalk.api.rest.OapiGetJsapiTicketRequest import OapiGetJsapiTicketRequest
from dingtalk.api.rest.OapiAppstoreOrdersInquiryRequest import OapiAppstoreOrdersInquiryRequest
from dingtalk.api.rest.OapiSmartdeviceFacegroupDeviceListRequest import OapiSmartdeviceFacegroupDeviceListRequest
from dingtalk.api.rest.OapiProcessinstanceVariableUpdateRequest import OapiProcessinstanceVariableUpdateRequest
from dingtalk.api.rest.OapiDdpaasObjectdataListRequest import OapiDdpaasObjectdataListRequest
from dingtalk.api.rest.OapiCspaceFilePresignedurlGetRequest import OapiCspaceFilePresignedurlGetRequest
from dingtalk.api.rest.OapiAtsResumeCheckexistenceRequest import OapiAtsResumeCheckexistenceRequest
from dingtalk.api.rest.OapiUserUpdateRequest import OapiUserUpdateRequest
from dingtalk.api.rest.OapiEduUserListRequest import OapiEduUserListRequest
from dingtalk.api.rest.OapiAuthScopesRequest import OapiAuthScopesRequest
from dingtalk.api.rest.OapiAttendanceVacationTypeCreateRequest import OapiAttendanceVacationTypeCreateRequest
from dingtalk.api.rest.OapiSmartdevicePrintdetailGetRequest import OapiSmartdevicePrintdetailGetRequest
from dingtalk.api.rest.OapiAttendanceGroupWifisAddRequest import OapiAttendanceGroupWifisAddRequest
from dingtalk.api.rest.OapiSceneservicegroupGroupGetRequest import OapiSceneservicegroupGroupGetRequest
from dingtalk.api.rest.OapiSmartdeviceFacegroupEnableRequest import OapiSmartdeviceFacegroupEnableRequest
from dingtalk.api.rest.OapiPbpInstanceGroupMemberListRequest import OapiPbpInstanceGroupMemberListRequest
from dingtalk.api.rest.OapiImChatServicegroupNoticeCreateRequest import OapiImChatServicegroupNoticeCreateRequest
from dingtalk.api.rest.CorpExtUpdateRequest import CorpExtUpdateRequest
from dingtalk.api.rest.OapiServiceaccountMenuUpdateRequest import OapiServiceaccountMenuUpdateRequest
from dingtalk.api.rest.OapiHrmEmployeeUpdateresumerecordRequest import OapiHrmEmployeeUpdateresumerecordRequest
from dingtalk.api.rest.OapiEduCourseGetRequest import OapiEduCourseGetRequest
from dingtalk.api.rest.OapiFinanceIdCardOcrRequest import OapiFinanceIdCardOcrRequest
from dingtalk.api.rest.CorpChatbotAddchatbotinstanceRequest import CorpChatbotAddchatbotinstanceRequest
from dingtalk.api.rest.OapiV2DepartmentListparentbyuserRequest import OapiV2DepartmentListparentbyuserRequest
from dingtalk.api.rest.OapiV2DepartmentListsubRequest import OapiV2DepartmentListsubRequest
from dingtalk.api.rest.OapiKacDatavVideoliveDetailListRequest import OapiKacDatavVideoliveDetailListRequest
from dingtalk.api.rest.OapiDepartmentListParentDeptsRequest import OapiDepartmentListParentDeptsRequest
from dingtalk.api.rest.OapiSmartdeviceVisitorAddvisitorRequest import OapiSmartdeviceVisitorAddvisitorRequest
from dingtalk.api.rest.OapiDingCreateRequest import OapiDingCreateRequest
from dingtalk.api.rest.OapiHrmEmployeeGetdismissionlistRequest import OapiHrmEmployeeGetdismissionlistRequest
from dingtalk.api.rest.OapiKacOpenliveRecordListRequest import OapiKacOpenliveRecordListRequest
from dingtalk.api.rest.OapiVillageScreenGetRequest import OapiVillageScreenGetRequest
from dingtalk.api.rest.OapiChatbotUninstallRequest import OapiChatbotUninstallRequest
from dingtalk.api.rest.OapiKacDatavDingGetRequest import OapiKacDatavDingGetRequest
from dingtalk.api.rest.OapiImChatControlgroupCreateRequest import OapiImChatControlgroupCreateRequest
from dingtalk.api.rest.OapiSmartdeviceExternalBindRequest import OapiSmartdeviceExternalBindRequest
from dingtalk.api.rest.OapiImChatScencegroupMessageSendRequest import OapiImChatScencegroupMessageSendRequest
from dingtalk.api.rest.CorpChatbotUpdatebychatbotidRequest import CorpChatbotUpdatebychatbotidRequest
from dingtalk.api.rest.OapiDepartmentCreateRequest import OapiDepartmentCreateRequest
from dingtalk.api.rest.OapiSceneservicegroupGroupQueryRequest import OapiSceneservicegroupGroupQueryRequest
from dingtalk.api.rest.OapiCrmMenuGetRequest import OapiCrmMenuGetRequest
from dingtalk.api.rest.OapiSmartworkHrmMasterCheckRequest import OapiSmartworkHrmMasterCheckRequest
from dingtalk.api.rest.OapiImIntelligentCardSendRequest import OapiImIntelligentCardSendRequest
from dingtalk.api.rest.OapiEduStudentGetRequest import OapiEduStudentGetRequest
from dingtalk.api.rest.OapiExtcontactGetRequest import OapiExtcontactGetRequest
from dingtalk.api.rest.OapiEduCourseListRequest import OapiEduCourseListRequest
from dingtalk.api.rest.CorpHrmEmployeeDelemployeedismissionandhandoverRequest import CorpHrmEmployeeDelemployeedismissionandhandoverRequest
from dingtalk.api.rest.OapiWorkspaceStatusUpdateRequest import OapiWorkspaceStatusUpdateRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeV2ListRequest import OapiSmartworkHrmEmployeeV2ListRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleQueryRequest import OapiAuthorizationRbacRoleQueryRequest
from dingtalk.api.rest.OapiDingmiRobotGetRequest import OapiDingmiRobotGetRequest
from dingtalk.api.rest.OapiCallBackDeleteCallBackRequest import OapiCallBackDeleteCallBackRequest
from dingtalk.api.rest.OapiAttendanceListscheduleRequest import OapiAttendanceListscheduleRequest
from dingtalk.api.rest.OapiExtcontactDeleteRequest import OapiExtcontactDeleteRequest
from dingtalk.api.rest.OapiSmartdeviceMeetingroomParticipantListRequest import OapiSmartdeviceMeetingroomParticipantListRequest
from dingtalk.api.rest.OapiEduHomeworkCommentTipsDeleteRequest import OapiEduHomeworkCommentTipsDeleteRequest
from dingtalk.api.rest.OapiRoleSimplelistRequest import OapiRoleSimplelistRequest
from dingtalk.api.rest.OapiProcessPropertyUpdateRequest import OapiProcessPropertyUpdateRequest
from dingtalk.api.rest.OapiAlitripBtripProjectDeleteRequest import OapiAlitripBtripProjectDeleteRequest
from dingtalk.api.rest.OapiRoleAddrolegroupRequest import OapiRoleAddrolegroupRequest
from dingtalk.api.rest.OapiEduSubjectUpdateRequest import OapiEduSubjectUpdateRequest
from dingtalk.api.rest.OapiSmartbotMsgPushRequest import OapiSmartbotMsgPushRequest
from dingtalk.api.rest.OapiSmartworkHrmOrganizationDeptMetaGetRequest import OapiSmartworkHrmOrganizationDeptMetaGetRequest
from dingtalk.api.rest.OapiIsvOpenencryptAuthappcloseRequest import OapiIsvOpenencryptAuthappcloseRequest
from dingtalk.api.rest.OapiUserCountRequest import OapiUserCountRequest
from dingtalk.api.rest.OapiEduDeptGetRequest import OapiEduDeptGetRequest
from dingtalk.api.rest.OapiSmartdeviceDeviceQueryRequest import OapiSmartdeviceDeviceQueryRequest
from dingtalk.api.rest.OapiEduGradeListRequest import OapiEduGradeListRequest
from dingtalk.api.rest.OapiIndustryUserListRequest import OapiIndustryUserListRequest
from dingtalk.api.rest.CorpHrmEmployeeAddresumerecordRequest import CorpHrmEmployeeAddresumerecordRequest
from dingtalk.api.rest.OapiSmartdeviceFacegroupDeviceUpdateRequest import OapiSmartdeviceFacegroupDeviceUpdateRequest
from dingtalk.api.rest.OapiProcessTemplateUpgradeRequest import OapiProcessTemplateUpgradeRequest
from dingtalk.api.rest.OapiReportSavecontentRequest import OapiReportSavecontentRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesSynccreateRequest import OapiRhinoMosExecClothesSynccreateRequest
from dingtalk.api.rest.OapiRhinoMosLayoutOperationdefGetflowRequest import OapiRhinoMosLayoutOperationdefGetflowRequest
from dingtalk.api.rest.CorpExtListRequest import CorpExtListRequest
from dingtalk.api.rest.OapiEduClassListbyteacherRequest import OapiEduClassListbyteacherRequest
from dingtalk.api.rest.OapiMessageCorpconversationAsyncsendRequest import OapiMessageCorpconversationAsyncsendRequest
from dingtalk.api.rest.OapiPlanetomFeedsCreateRequest import OapiPlanetomFeedsCreateRequest
from dingtalk.api.rest.OapiMicroappRuleGetUserTotalRequest import OapiMicroappRuleGetUserTotalRequest
from dingtalk.api.rest.OapiRhinoMosExecPerformStartRequest import OapiRhinoMosExecPerformStartRequest
from dingtalk.api.rest.OapiAlitripBtripProjectModifyRequest import OapiAlitripBtripProjectModifyRequest
from dingtalk.api.rest.OapiEduPeriodCreateRequest import OapiEduPeriodCreateRequest
from dingtalk.api.rest.OapiAlitripBtripApplySearchRequest import OapiAlitripBtripApplySearchRequest
from dingtalk.api.rest.OapiWorkbenchShortcutUpdateRequest import OapiWorkbenchShortcutUpdateRequest
from dingtalk.api.rest.OapiAtsEvaluateJobmatchCancelRequest import OapiAtsEvaluateJobmatchCancelRequest
from dingtalk.api.rest.OapiPbpInstanceEnableRequest import OapiPbpInstanceEnableRequest
from dingtalk.api.rest.OapiProcessFormGetRequest import OapiProcessFormGetRequest
from dingtalk.api.rest.OapiAttendanceShiftAddRequest import OapiAttendanceShiftAddRequest
from dingtalk.api.rest.OapiBlackboardGetRequest import OapiBlackboardGetRequest
from dingtalk.api.rest.OapiAttendanceListRequest import OapiAttendanceListRequest
from dingtalk.api.rest.OapiOpenencryptUpdateconfigRequest import OapiOpenencryptUpdateconfigRequest
from dingtalk.api.rest.OapiProcessInstanceCommentAddRequest import OapiProcessInstanceCommentAddRequest
from dingtalk.api.rest.OapiAttendanceGroupsKeytoidRequest import OapiAttendanceGroupsKeytoidRequest
from dingtalk.api.rest.OapiDingSendRequest import OapiDingSendRequest
from dingtalk.api.rest.OapiNewmanufacturerOrderGetRequest import OapiNewmanufacturerOrderGetRequest
from dingtalk.api.rest.OapiCallBackRegisterCallBackRequest import OapiCallBackRegisterCallBackRequest
from dingtalk.api.rest.OapiUserGetAdminRequest import OapiUserGetAdminRequest
from dingtalk.api.rest.OapiFinanceFaceVerificationQueryRequest import OapiFinanceFaceVerificationQueryRequest
from dingtalk.api.rest.OapiOrgListshortcutRequest import OapiOrgListshortcutRequest
from dingtalk.api.rest.OapiReportCreateRequest import OapiReportCreateRequest
from dingtalk.api.rest.SmartworkAttendsListscheduleRequest import SmartworkAttendsListscheduleRequest
from dingtalk.api.rest.OapiCustomizeConversationUpdateRequest import OapiCustomizeConversationUpdateRequest
from dingtalk.api.rest.OapiCollectionInstanceListRequest import OapiCollectionInstanceListRequest
from dingtalk.api.rest.OapiCspaceAddToSingleChatRequest import OapiCspaceAddToSingleChatRequest
from dingtalk.api.rest.OapiEduHomeworkCommentTipsCreateRequest import OapiEduHomeworkCommentTipsCreateRequest
from dingtalk.api.rest.OapiEduCampusListRequest import OapiEduCampusListRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleMemberRemoveRequest import OapiAuthorizationRbacRoleMemberRemoveRequest
from dingtalk.api.rest.OapiEduUserRelationGetRequest import OapiEduUserRelationGetRequest
from dingtalk.api.rest.OapiEduTypeDataGetRequest import OapiEduTypeDataGetRequest
from dingtalk.api.rest.OapiKacDatavTelconfGetRequest import OapiKacDatavTelconfGetRequest
from dingtalk.api.rest.OapiRhinoMosSpacePoiGetRequest import OapiRhinoMosSpacePoiGetRequest
from dingtalk.api.rest.OapiAttendanceShiftQueryRequest import OapiAttendanceShiftQueryRequest
from dingtalk.api.rest.OapiCrmObjectmetaCustomerDescribeRequest import OapiCrmObjectmetaCustomerDescribeRequest
from dingtalk.api.rest.OapiV2UserDeleteRequest import OapiV2UserDeleteRequest
from dingtalk.api.rest.OapiAlitripBtripMonthbillUrlGetRequest import OapiAlitripBtripMonthbillUrlGetRequest
from dingtalk.api.rest.OapiAlitripBtripAddressGetRequest import OapiAlitripBtripAddressGetRequest
from dingtalk.api.rest.OapiInactiveUserGetRequest import OapiInactiveUserGetRequest
from dingtalk.api.rest.OapiHealthStepinfoListbyuseridRequest import OapiHealthStepinfoListbyuseridRequest
from dingtalk.api.rest.OapiProcessTemplateListRequest import OapiProcessTemplateListRequest
from dingtalk.api.rest.CorpEncryptionKeyListRequest import CorpEncryptionKeyListRequest
from dingtalk.api.rest.OapiHealthStepinfoListRequest import OapiHealthStepinfoListRequest
from dingtalk.api.rest.OapiSmartworkHrmMasterDeleteRequest import OapiSmartworkHrmMasterDeleteRequest
from dingtalk.api.rest.OapiCustomerserviceEventChangeRequest import OapiCustomerserviceEventChangeRequest
from dingtalk.api.rest.OapiChatTagDeleteRequest import OapiChatTagDeleteRequest
from dingtalk.api.rest.OapiV2UserUpdateRequest import OapiV2UserUpdateRequest
from dingtalk.api.rest.SmartworkBpmsProcessinstanceExecuteRequest import SmartworkBpmsProcessinstanceExecuteRequest
from dingtalk.api.rest.OapiRhinoMosLayoutOperationdefsSectionfirstRequest import OapiRhinoMosLayoutOperationdefsSectionfirstRequest
from dingtalk.api.rest.OapiCrmObjectdataCustomerDeleteRequest import OapiCrmObjectdataCustomerDeleteRequest
from dingtalk.api.rest.OapiImChatScenegroupTemplateApplyRequest import OapiImChatScenegroupTemplateApplyRequest
from dingtalk.api.rest.OapiBlackboardUpdateRequest import OapiBlackboardUpdateRequest
from dingtalk.api.rest.OapiImChatbotGetRequest import OapiImChatbotGetRequest
from dingtalk.api.rest.OapiWorkspaceCorpMemberAddRequest import OapiWorkspaceCorpMemberAddRequest
from dingtalk.api.rest.OapiMicroappRuleGetRuleListRequest import OapiMicroappRuleGetRuleListRequest
from dingtalk.api.rest.OapiAlitripBtripApplyGetRequest import OapiAlitripBtripApplyGetRequest
from dingtalk.api.rest.OapiRhinoMosSpaceDeviceCheckInListbydeviceRequest import OapiRhinoMosSpaceDeviceCheckInListbydeviceRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleResourceUpdateRequest import OapiAuthorizationRbacRoleResourceUpdateRequest
from dingtalk.api.rest.OapiAppstoreGoodsQueryRequest import OapiAppstoreGoodsQueryRequest
from dingtalk.api.rest.OapiGettokenRequest import OapiGettokenRequest
from dingtalk.api.rest.OapiImChatScencegroupMessageSendV2Request import OapiImChatScencegroupMessageSendV2Request
from dingtalk.api.rest.OapiIsvOpenencryptHeartbeatRequest import OapiIsvOpenencryptHeartbeatRequest
from dingtalk.api.rest.OapiCallBackGetCallBackRequest import OapiCallBackGetCallBackRequest
from dingtalk.api.rest.OapiAtsChannelAccountAddRequest import OapiAtsChannelAccountAddRequest
from dingtalk.api.rest.OapiFileUploadChunkRequest import OapiFileUploadChunkRequest
from dingtalk.api.rest.OapiWorkbenchShortcutAddRequest import OapiWorkbenchShortcutAddRequest
from dingtalk.api.rest.OapiAttendanceGroupCreateRequest import OapiAttendanceGroupCreateRequest
from dingtalk.api.rest.OapiCalendarDeleteRequest import OapiCalendarDeleteRequest
from dingtalk.api.rest.OapiCrmObjectdataContactCreateRequest import OapiCrmObjectdataContactCreateRequest
from dingtalk.api.rest.OapiDingmiGroupGetRequest import OapiDingmiGroupGetRequest
from dingtalk.api.rest.OapiConferenceParticipantSyncRequest import OapiConferenceParticipantSyncRequest
from dingtalk.api.rest.OapiFinanceUserAuthInfoQueryRequest import OapiFinanceUserAuthInfoQueryRequest
from dingtalk.api.rest.OapiMicroappSetVisibleScopesRequest import OapiMicroappSetVisibleScopesRequest
from dingtalk.api.rest.OapiEduCertGetRequest import OapiEduCertGetRequest
from dingtalk.api.rest.OapiKacDatavTelconfDetailListRequest import OapiKacDatavTelconfDetailListRequest
from dingtalk.api.rest.OapiWikiDocDetailRequest import OapiWikiDocDetailRequest
from dingtalk.api.rest.OapiMicroappCustomCreateRequest import OapiMicroappCustomCreateRequest
from dingtalk.api.rest.OapiMicroappListByUseridRequest import OapiMicroappListByUseridRequest
from dingtalk.api.rest.OapiProcessTemplateUpgradeinfoQueryRequest import OapiProcessTemplateUpgradeinfoQueryRequest
from dingtalk.api.rest.OapiImpaasUserModprofileRequest import OapiImpaasUserModprofileRequest
from dingtalk.api.rest.OapiEduCourseDeleteRequest import OapiEduCourseDeleteRequest
from dingtalk.api.rest.OapiAppstoreInternalSkupageGetRequest import OapiAppstoreInternalSkupageGetRequest
from dingtalk.api.rest.OapiExtcontactListlabelgroupsRequest import OapiExtcontactListlabelgroupsRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeListbycertRequest import OapiSmartworkHrmEmployeeListbycertRequest
from dingtalk.api.rest.OapiMessageCorpconversationStatusBarUpdateRequest import OapiMessageCorpconversationStatusBarUpdateRequest
from dingtalk.api.rest.OapiDingpayBillBatchquerycountRequest import OapiDingpayBillBatchquerycountRequest
from dingtalk.api.rest.OapiSmartdeviceAtmachineGetByUseridRequest import OapiSmartdeviceAtmachineGetByUseridRequest
from dingtalk.api.rest.OapiAlitripBtripApprovalNewRequest import OapiAlitripBtripApprovalNewRequest
from dingtalk.api.rest.OapiAttendanceVacationTypeUpdateRequest import OapiAttendanceVacationTypeUpdateRequest
from dingtalk.api.rest.OapiWikiResourceAuthRequest import OapiWikiResourceAuthRequest
from dingtalk.api.rest.OapiDingmiRobotUpdateRequest import OapiDingmiRobotUpdateRequest
from dingtalk.api.rest.OapiCspaceAuthUpdateRequest import OapiCspaceAuthUpdateRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeUnionexportRequest import OapiSmartworkHrmEmployeeUnionexportRequest
from dingtalk.api.rest.OapiEduTeacherCreateRequest import OapiEduTeacherCreateRequest
from dingtalk.api.rest.OapiImpaasUserGetprofileRequest import OapiImpaasUserGetprofileRequest
from dingtalk.api.rest.OapiKacOpenliveWhiteUsersListRequest import OapiKacOpenliveWhiteUsersListRequest
from dingtalk.api.rest.OapiSmartdeviceAtmachineGetByDeptidRequest import OapiSmartdeviceAtmachineGetByDeptidRequest
from dingtalk.api.rest.OapiRoleAddrolesforempsRequest import OapiRoleAddrolesforempsRequest
from dingtalk.api.rest.OapiOrgSetoaurlRequest import OapiOrgSetoaurlRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeQuerypreentryRequest import OapiSmartworkHrmEmployeeQuerypreentryRequest
from dingtalk.api.rest.OapiAttendanceIsopensmartreportRequest import OapiAttendanceIsopensmartreportRequest
from dingtalk.api.rest.OapiRobotSendRequest import OapiRobotSendRequest
from dingtalk.api.rest.OapiChatBanwordsQueryRequest import OapiChatBanwordsQueryRequest
from dingtalk.api.rest.IsvBlazersGeneratecodeRequest import IsvBlazersGeneratecodeRequest
from dingtalk.api.rest.OapiExtcontactUpdateRequest import OapiExtcontactUpdateRequest
from dingtalk.api.rest.OapiCrmObjectdataContactUpdateRequest import OapiCrmObjectdataContactUpdateRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleMemberAddRequest import OapiAuthorizationRbacRoleMemberAddRequest
from dingtalk.api.rest.IsvCallSetuserlistRequest import IsvCallSetuserlistRequest
from dingtalk.api.rest.OapiPbpInstanceGroupCreateRequest import OapiPbpInstanceGroupCreateRequest
from dingtalk.api.rest.OapiAuthorizationRbacPermissionGetRequest import OapiAuthorizationRbacPermissionGetRequest
from dingtalk.api.rest.OapiReportStatisticsRequest import OapiReportStatisticsRequest
from dingtalk.api.rest.OapiCspaceGetCustomSpaceRequest import OapiCspaceGetCustomSpaceRequest
from dingtalk.api.rest.CorpBlazersGetbinddataRequest import CorpBlazersGetbinddataRequest
from dingtalk.api.rest.OapiEduHomeworkStudentCommentListRequest import OapiEduHomeworkStudentCommentListRequest
from dingtalk.api.rest.OapiKacOpenliveWhiteUsersBatchDeleteRequest import OapiKacOpenliveWhiteUsersBatchDeleteRequest
from dingtalk.api.rest.OapiAttendanceGroupMemberListbyidsRequest import OapiAttendanceGroupMemberListbyidsRequest
from dingtalk.api.rest.OapiChatUpdateRequest import OapiChatUpdateRequest
from dingtalk.api.rest.OapiAlitripBtripInvoiceSettingModifyRequest import OapiAlitripBtripInvoiceSettingModifyRequest
from dingtalk.api.rest.OapiWorkspaceTaskMigrateRequest import OapiWorkspaceTaskMigrateRequest
from dingtalk.api.rest.OapiMicroappCustomDeleteRequest import OapiMicroappCustomDeleteRequest
from dingtalk.api.rest.OapiCallSetuserlistRequest import OapiCallSetuserlistRequest
from dingtalk.api.rest.OapiCrmObjectmetaContactDescribeRequest import OapiCrmObjectmetaContactDescribeRequest
from dingtalk.api.rest.CorpSmartdeviceReceptionistPushinfoRequest import CorpSmartdeviceReceptionistPushinfoRequest
from dingtalk.api.rest.OapiEduCourseUpdateRequest import OapiEduCourseUpdateRequest
from dingtalk.api.rest.OapiUserListadminRequest import OapiUserListadminRequest
from dingtalk.api.rest.CorpHrmEmployeeGetRequest import CorpHrmEmployeeGetRequest
from dingtalk.api.rest.OapiCrmObjectdataCustomerListRequest import OapiCrmObjectdataCustomerListRequest
from dingtalk.api.rest.OapiAlitripBtripBindTaobaoGetRequest import OapiAlitripBtripBindTaobaoGetRequest
from dingtalk.api.rest.OapiAtsJobQueryRequest import OapiAtsJobQueryRequest
from dingtalk.api.rest.OapiMaterialArticleAddRequest import OapiMaterialArticleAddRequest
from dingtalk.api.rest.OapiFinanceLoanNotifyLendRequest import OapiFinanceLoanNotifyLendRequest
from dingtalk.api.rest.OapiOrgUnionBranchGetRequest import OapiOrgUnionBranchGetRequest
from dingtalk.api.rest.OapiEduRolesGetRequest import OapiEduRolesGetRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleNameUpdateRequest import OapiAuthorizationRbacRoleNameUpdateRequest
from dingtalk.api.rest.OapiRoleDeleteroleRequest import OapiRoleDeleteroleRequest
from dingtalk.api.rest.OapiOcrStructuredRecognizeRequest import OapiOcrStructuredRecognizeRequest
from dingtalk.api.rest.OapiChatUpdatebanwordsRequest import OapiChatUpdatebanwordsRequest
from dingtalk.api.rest.OapiAlitripBtripCostCenterModifyRequest import OapiAlitripBtripCostCenterModifyRequest
from dingtalk.api.rest.OapiCcoserviceServicegroupGetRequest import OapiCcoserviceServicegroupGetRequest
from dingtalk.api.rest.OapiSmartworkHrmNavigationbarConfigGetRequest import OapiSmartworkHrmNavigationbarConfigGetRequest
from dingtalk.api.rest.OapiReportTemplateGetbynameRequest import OapiReportTemplateGetbynameRequest
from dingtalk.api.rest.OapiImChatScencegroupInteractivecardSendRequest import OapiImChatScencegroupInteractivecardSendRequest
from dingtalk.api.rest.OapiAttendanceGroupUsersRemoveRequest import OapiAttendanceGroupUsersRemoveRequest
from dingtalk.api.rest.OapiV2UserGetRequest import OapiV2UserGetRequest
from dingtalk.api.rest.CorpMessageCorpconversationAsyncsendRequest import CorpMessageCorpconversationAsyncsendRequest
from dingtalk.api.rest.IsvCallGetuserlistRequest import IsvCallGetuserlistRequest
from dingtalk.api.rest.OapiMiniappDeploywindowQueryRequest import OapiMiniappDeploywindowQueryRequest
from dingtalk.api.rest.OapiEduAlumniGetRequest import OapiEduAlumniGetRequest
from dingtalk.api.rest.CorpMessageCorpconversationGetsendresultRequest import CorpMessageCorpconversationGetsendresultRequest
from dingtalk.api.rest.OapiReportSimplelistRequest import OapiReportSimplelistRequest
from dingtalk.api.rest.OapiKacDatavDeptVideoconfListRequest import OapiKacDatavDeptVideoconfListRequest
from dingtalk.api.rest.OapiV2UserGetbymobileRequest import OapiV2UserGetbymobileRequest
from dingtalk.api.rest.OapiImChatScenegroupGetRequest import OapiImChatScenegroupGetRequest
from dingtalk.api.rest.OapiAlitripBtripTrainOrderSearchRequest import OapiAlitripBtripTrainOrderSearchRequest
from dingtalk.api.rest.OapiSmartdeviceEventPostRequest import OapiSmartdeviceEventPostRequest
from dingtalk.api.rest.OapiKacDatavDeptChatSummaryListRequest import OapiKacDatavDeptChatSummaryListRequest
from dingtalk.api.rest.OapiImpaasUserSubaccountDeleteRequest import OapiImpaasUserSubaccountDeleteRequest
from dingtalk.api.rest.OapiEduMainDataGetRequest import OapiEduMainDataGetRequest
from dingtalk.api.rest.OapiHireBizflowStartRequest import OapiHireBizflowStartRequest
from dingtalk.api.rest.OapiBlackboardDeleteRequest import OapiBlackboardDeleteRequest
from dingtalk.api.rest.OapiWikiDocPublicDetailRequest import OapiWikiDocPublicDetailRequest
from dingtalk.api.rest.OapiCallbackFailrecordListRequest import OapiCallbackFailrecordListRequest
from dingtalk.api.rest.OapiAtsResumeAddRequest import OapiAtsResumeAddRequest
from dingtalk.api.rest.OapiEduClassGetRequest import OapiEduClassGetRequest
from dingtalk.api.rest.OapiRobotOrgIntelligentMessageSendRequest import OapiRobotOrgIntelligentMessageSendRequest
from dingtalk.api.rest.OapiImChatScencegroupInteractivecardCallbackRegisterRequest import OapiImChatScencegroupInteractivecardCallbackRegisterRequest
from dingtalk.api.rest.CorpRoleRemoverolesforempsRequest import CorpRoleRemoverolesforempsRequest
from dingtalk.api.rest.OapiOrgUserteaminviteAcceptRequest import OapiOrgUserteaminviteAcceptRequest
from dingtalk.api.rest.OapiUnionCooperateInfoListRequest import OapiUnionCooperateInfoListRequest
from dingtalk.api.rest.OapiAttendanceFaceRecognitionRequest import OapiAttendanceFaceRecognitionRequest
from dingtalk.api.rest.OapiAttendanceVacationQuotaUpdateRequest import OapiAttendanceVacationQuotaUpdateRequest
from dingtalk.api.rest.OapiProcessPrinterInstanceGetRequest import OapiProcessPrinterInstanceGetRequest
from dingtalk.api.rest.OapiBlackboardListtoptenRequest import OapiBlackboardListtoptenRequest
from dingtalk.api.rest.OapiRobotMessageOrggrouptaskQueryRequest import OapiRobotMessageOrggrouptaskQueryRequest
from dingtalk.api.rest.OapiProcessWorkrecordTaskCreateRequest import OapiProcessWorkrecordTaskCreateRequest
from dingtalk.api.rest.OapiDingpayOrderSyncstatusRequest import OapiDingpayOrderSyncstatusRequest
from dingtalk.api.rest.OapiAttendanceShiftDeleteRequest import OapiAttendanceShiftDeleteRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesGetRequest import OapiRhinoMosExecClothesGetRequest
from dingtalk.api.rest.OapiUserListsimpleRequest import OapiUserListsimpleRequest
from dingtalk.api.rest.OapiImpaasConversationModifymemberRequest import OapiImpaasConversationModifymemberRequest
from dingtalk.api.rest.OapiHrmEmployeeGetRequest import OapiHrmEmployeeGetRequest
from dingtalk.api.rest.OapiDepartmentListIdsRequest import OapiDepartmentListIdsRequest
from dingtalk.api.rest.OapiProcessWorkrecordTaskQueryRequest import OapiProcessWorkrecordTaskQueryRequest
from dingtalk.api.rest.OapiKacDatavDauSummaryGetRequest import OapiKacDatavDauSummaryGetRequest
from dingtalk.api.rest.OapiKacDatavInactivatedUserListRequest import OapiKacDatavInactivatedUserListRequest
from dingtalk.api.rest.OapiProcessinstanceFileDownloadRequest import OapiProcessinstanceFileDownloadRequest
from dingtalk.api.rest.OapiSmartdeviceVisitorEditvisitorRequest import OapiSmartdeviceVisitorEditvisitorRequest
from dingtalk.api.rest.OapiEduHomeworkStudentReportSubmitRequest import OapiEduHomeworkStudentReportSubmitRequest
from dingtalk.api.rest.OapiChatGetReadListRequest import OapiChatGetReadListRequest
from dingtalk.api.rest.OapiRhinoMosSpaceWorkerCheckInRequest import OapiRhinoMosSpaceWorkerCheckInRequest
from dingtalk.api.rest.OapiEduClassStudentBatchgetRequest import OapiEduClassStudentBatchgetRequest
from dingtalk.api.rest.OapiImChatServicegroupMemberUpdateRequest import OapiImChatServicegroupMemberUpdateRequest
from dingtalk.api.rest.OapiEduClassStudentListRequest import OapiEduClassStudentListRequest
from dingtalk.api.rest.OapiMiniappMiniappversionQueryRequest import OapiMiniappMiniappversionQueryRequest
from dingtalk.api.rest.OapiUserListbypageRequest import OapiUserListbypageRequest
from dingtalk.api.rest.OapiRetailSellerQueryRequest import OapiRetailSellerQueryRequest
from dingtalk.api.rest.OapiChatTagSetRequest import OapiChatTagSetRequest
from dingtalk.api.rest.OapiEduTeacherListRequest import OapiEduTeacherListRequest
from dingtalk.api.rest.OapiInactiveUserV2GetRequest import OapiInactiveUserV2GetRequest
from dingtalk.api.rest.OapiImpaasRelationAddRequest import OapiImpaasRelationAddRequest
from dingtalk.api.rest.OapiDingpayOrderTerminateRequest import OapiDingpayOrderTerminateRequest
from dingtalk.api.rest.OapiKacDatavVideoconfGetRequest import OapiKacDatavVideoconfGetRequest
from dingtalk.api.rest.OapiMicroappCreateRequest import OapiMicroappCreateRequest
from dingtalk.api.rest.OapiRhinoMosExecTrackUnbindRequest import OapiRhinoMosExecTrackUnbindRequest
from dingtalk.api.rest.OapiImpaasRelationGetRequest import OapiImpaasRelationGetRequest
from dingtalk.api.rest.OapiV2DepartmentCreateRequest import OapiV2DepartmentCreateRequest
from dingtalk.api.rest.OapiServicegroupMessageSendRequest import OapiServicegroupMessageSendRequest
from dingtalk.api.rest.OapiAttendanceScheduleListbydayRequest import OapiAttendanceScheduleListbydayRequest
from dingtalk.api.rest.OapiV2UserGetuserinfoRequest import OapiV2UserGetuserinfoRequest
from dingtalk.api.rest.OapiDingmiCommonLoginAccesstokenRequest import OapiDingmiCommonLoginAccesstokenRequest
from dingtalk.api.rest.CorpExtDeleteRequest import CorpExtDeleteRequest
from dingtalk.api.rest.OapiCrmObjectdataQueryRequest import OapiCrmObjectdataQueryRequest
from dingtalk.api.rest.CorpHrmEmployeeModjobinfoRequest import CorpHrmEmployeeModjobinfoRequest
from dingtalk.api.rest.OapiChatChatidTransformqrcodeGetRequest import OapiChatChatidTransformqrcodeGetRequest
from dingtalk.api.rest.OapiEduHomeworkStudentSubmitRequest import OapiEduHomeworkStudentSubmitRequest
from dingtalk.api.rest.OapiProcessBaseinfoListRequest import OapiProcessBaseinfoListRequest
from dingtalk.api.rest.OapiEduCircleTopiclistRequest import OapiEduCircleTopiclistRequest
from dingtalk.api.rest.OapiCustomerserviceActionQueryRequest import OapiCustomerserviceActionQueryRequest
from dingtalk.api.rest.OapiRetailSellerSyncRequest import OapiRetailSellerSyncRequest
from dingtalk.api.rest.OapiSmartdeviceDeviceUnbindRequest import OapiSmartdeviceDeviceUnbindRequest
from dingtalk.api.rest.OapiHrmEmployeeAddresumerecordRequest import OapiHrmEmployeeAddresumerecordRequest
from dingtalk.api.rest.OapiProcessDeleteRequest import OapiProcessDeleteRequest
from dingtalk.api.rest.OapiPbpInstancePositionListRequest import OapiPbpInstancePositionListRequest
from dingtalk.api.rest.OapiProcessWorkrecordTaskgroupCancelRequest import OapiProcessWorkrecordTaskgroupCancelRequest
from dingtalk.api.rest.OapiImChatCidConvertRequest import OapiImChatCidConvertRequest
from dingtalk.api.rest.OapiSmartworkHrmSmsSendforpayslipRequest import OapiSmartworkHrmSmsSendforpayslipRequest
from dingtalk.api.rest.OapiEduPeriodListRequest import OapiEduPeriodListRequest
from dingtalk.api.rest.SmartworkBlackboardListtoptenRequest import SmartworkBlackboardListtoptenRequest
from dingtalk.api.rest.CorpConversationCorpconversionGetconversationRequest import CorpConversationCorpconversionGetconversationRequest
from dingtalk.api.rest.OapiImpaasGroupGetbydeptidRequest import OapiImpaasGroupGetbydeptidRequest
from dingtalk.api.rest.OapiV2UserCreateRequest import OapiV2UserCreateRequest
from dingtalk.api.rest.OapiMedalCorpmedalWearRequest import OapiMedalCorpmedalWearRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesCreateRequest import OapiRhinoMosExecClothesCreateRequest
from dingtalk.api.rest.OapiMessageMassSendRequest import OapiMessageMassSendRequest
from dingtalk.api.rest.OapiUserGetDeptMemberRequest import OapiUserGetDeptMemberRequest
from dingtalk.api.rest.OapiMicroappDelwithuseridRequest import OapiMicroappDelwithuseridRequest
from dingtalk.api.rest.OapiCrmGroupCreateRequest import OapiCrmGroupCreateRequest
from dingtalk.api.rest.OapiEduCampusGetRequest import OapiEduCampusGetRequest
from dingtalk.api.rest.OapiUserGetUseridByUnionidRequest import OapiUserGetUseridByUnionidRequest
from dingtalk.api.rest.OapiChatCreateRequest import OapiChatCreateRequest
from dingtalk.api.rest.CorpChatbotListorgbotbytypeandbottypeRequest import CorpChatbotListorgbotbytypeandbottypeRequest
from dingtalk.api.rest.OapiAttendanceCorpConfirmRequest import OapiAttendanceCorpConfirmRequest
from dingtalk.api.rest.OapiAttendanceGroupsIdtokeyRequest import OapiAttendanceGroupsIdtokeyRequest
from dingtalk.api.rest.OapiAttendanceAdvancedServiceUnbindRequest import OapiAttendanceAdvancedServiceUnbindRequest
from dingtalk.api.rest.OapiAlitripBtripHotelOrderSearchRequest import OapiAlitripBtripHotelOrderSearchRequest
from dingtalk.api.rest.OapiEduCourseDetaildataListRequest import OapiEduCourseDetaildataListRequest
from dingtalk.api.rest.CorpSmartdeviceHasfaceRequest import CorpSmartdeviceHasfaceRequest
from dingtalk.api.rest.OapiMicroappRuleDeleteRequest import OapiMicroappRuleDeleteRequest
from dingtalk.api.rest.OapiRoleListRequest import OapiRoleListRequest
from dingtalk.api.rest.OapiAlitripBtripReimbursementUpdateRequest import OapiAlitripBtripReimbursementUpdateRequest
from dingtalk.api.rest.OapiConnectorTriggerSendV2Request import OapiConnectorTriggerSendV2Request
from dingtalk.api.rest.OapiKacDatavDeptTelconfListRequest import OapiKacDatavDeptTelconfListRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesBatchUnscrapRequest import OapiRhinoMosExecClothesBatchUnscrapRequest
from dingtalk.api.rest.OapiSmartdeviceMeetingroomListRequest import OapiSmartdeviceMeetingroomListRequest
from dingtalk.api.rest.OapiCrmObjectdataContactListRequest import OapiCrmObjectdataContactListRequest
from dingtalk.api.rest.OapiEduCourseCancelRequest import OapiEduCourseCancelRequest
from dingtalk.api.rest.OapiMicroappScopeAddRequest import OapiMicroappScopeAddRequest
from dingtalk.api.rest.OapiKacV2DatavVideoconfGetRequest import OapiKacV2DatavVideoconfGetRequest
from dingtalk.api.rest.OapiSmartdeviceHasfaceRequest import OapiSmartdeviceHasfaceRequest
from dingtalk.api.rest.CorpChatbotListorgbotRequest import CorpChatbotListorgbotRequest
from dingtalk.api.rest.OapiIndustryPackGetRequest import OapiIndustryPackGetRequest
from dingtalk.api.rest.OapiV2UserListRequest import OapiV2UserListRequest
from dingtalk.api.rest.OapiUserGetAdminScopeRequest import OapiUserGetAdminScopeRequest
from dingtalk.api.rest.OapiCallBackUpdateCallBackRequest import OapiCallBackUpdateCallBackRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeListcontactRequest import OapiSmartworkHrmEmployeeListcontactRequest
from dingtalk.api.rest.OapiEduCirclePostListRequest import OapiEduCirclePostListRequest
from dingtalk.api.rest.OapiDingtaxGroupdaudataGetRequest import OapiDingtaxGroupdaudataGetRequest
from dingtalk.api.rest.OapiKacDatavGroupGetRequest import OapiKacDatavGroupGetRequest
from dingtalk.api.rest.OapiCheckinRecordGetRequest import OapiCheckinRecordGetRequest
from dingtalk.api.rest.OapiProcessProcvisibleSaveRequest import OapiProcessProcvisibleSaveRequest
from dingtalk.api.rest.CorpMessageCorpconversationAsyncsendbycodeRequest import CorpMessageCorpconversationAsyncsendbycodeRequest
from dingtalk.api.rest.OapiProcessApproversForecastRequest import OapiProcessApproversForecastRequest
from dingtalk.api.rest.CorpRoleDeleteroleRequest import CorpRoleDeleteroleRequest
from dingtalk.api.rest.OapiRhinoHumanresCorpemployeeGetRequest import OapiRhinoHumanresCorpemployeeGetRequest
from dingtalk.api.rest.OapiSmartworkHrmMasterSaveRequest import OapiSmartworkHrmMasterSaveRequest
from dingtalk.api.rest.OapiMediaUploadRequest import OapiMediaUploadRequest
from dingtalk.api.rest.CorpExtcontactListRequest import CorpExtcontactListRequest
from dingtalk.api.rest.OapiEduHomeworkCommentTipsQueryRequest import OapiEduHomeworkCommentTipsQueryRequest
from dingtalk.api.rest.OapiRhinoMosExecPerformQueryRequest import OapiRhinoMosExecPerformQueryRequest
from dingtalk.api.rest.OapiAtsJobDeliverAddRequest import OapiAtsJobDeliverAddRequest
from dingtalk.api.rest.OapiImChatServicegroupDisbandRequest import OapiImChatServicegroupDisbandRequest
from dingtalk.api.rest.OapiWorkspaceProjectCreateRequest import OapiWorkspaceProjectCreateRequest
from dingtalk.api.rest.OapiAtsPluginStatisticsResumeListRequest import OapiAtsPluginStatisticsResumeListRequest
from dingtalk.api.rest.OapiEduPeriodMetadataListRequest import OapiEduPeriodMetadataListRequest
from dingtalk.api.rest.OapiCspaceGrantCustomSpaceRequest import OapiCspaceGrantCustomSpaceRequest
from dingtalk.api.rest.CorpHrmEmployeeGetdismissionlistRequest import CorpHrmEmployeeGetdismissionlistRequest
from dingtalk.api.rest.OapiWorkbenchShortcutListRequest import OapiWorkbenchShortcutListRequest
from dingtalk.api.rest.CorpDeviceManageGetRequest import CorpDeviceManageGetRequest
from dingtalk.api.rest.OapiSnsGetPersistentCodeRequest import OapiSnsGetPersistentCodeRequest
from dingtalk.api.rest.SmartworkCheckinRecordGetRequest import SmartworkCheckinRecordGetRequest
from dingtalk.api.rest.OapiUserSeniorWhitelistSetRequest import OapiUserSeniorWhitelistSetRequest
from dingtalk.api.rest.OapiEduPeriodGetRequest import OapiEduPeriodGetRequest
from dingtalk.api.rest.OapiEduCourseSummadataListRequest import OapiEduCourseSummadataListRequest
from dingtalk.api.rest.OapiProcessinstanceGetRequest import OapiProcessinstanceGetRequest
from dingtalk.api.rest.SmartworkAttendsGetleaveapprovedurationRequest import SmartworkAttendsGetleaveapprovedurationRequest
from dingtalk.api.rest.OapiIndustryUserGetRequest import OapiIndustryUserGetRequest
from dingtalk.api.rest.OapiCrmObjectdataFollowrecordListRequest import OapiCrmObjectdataFollowrecordListRequest
from dingtalk.api.rest.OapiRoleVisibleGetRequest import OapiRoleVisibleGetRequest
from dingtalk.api.rest.OapiAlitripBtripFlightCitySuggestRequest import OapiAlitripBtripFlightCitySuggestRequest
from dingtalk.api.rest.OapiCustomerserviceSessionCloseRequest import OapiCustomerserviceSessionCloseRequest
from dingtalk.api.rest.OapiAtsPluginDataDeleteRequest import OapiAtsPluginDataDeleteRequest
from dingtalk.api.rest.OapiUnionCooperateJoinedListRequest import OapiUnionCooperateJoinedListRequest
from dingtalk.api.rest.OapiCustomerserviceStatusUpdateRequest import OapiCustomerserviceStatusUpdateRequest
from dingtalk.api.rest.OapiCustomerserviceTicketQueryRequest import OapiCustomerserviceTicketQueryRequest
from dingtalk.api.rest.SmartworkBpmsProcessinstanceCreateRequest import SmartworkBpmsProcessinstanceCreateRequest
from dingtalk.api.rest.OapiAttendanceScheduleShiftListbydaysRequest import OapiAttendanceScheduleShiftListbydaysRequest
from dingtalk.api.rest.OapiEduClassListRequest import OapiEduClassListRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleMemberListRequest import OapiAuthorizationRbacRoleMemberListRequest
from dingtalk.api.rest.OapiOrgUnionTrunkGetRequest import OapiOrgUnionTrunkGetRequest
from dingtalk.api.rest.OapiProcessActivityinfoGetRequest import OapiProcessActivityinfoGetRequest
from dingtalk.api.rest.OapiImChatScenegroupMemberGetRequest import OapiImChatScenegroupMemberGetRequest
from dingtalk.api.rest.OapiOrgSetshortcutRequest import OapiOrgSetshortcutRequest
from dingtalk.api.rest.OapiWorkspaceTasklistAddbyprojectRequest import OapiWorkspaceTasklistAddbyprojectRequest
from dingtalk.api.rest.OapiImGroupappSysmsgSendRequest import OapiImGroupappSysmsgSendRequest
from dingtalk.api.rest.OapiWikiRepoListRequest import OapiWikiRepoListRequest
from dingtalk.api.rest.OapiImChatServicegroupUpgradeRequest import OapiImChatServicegroupUpgradeRequest
from dingtalk.api.rest.OapiProcessinstanceCreateRequest import OapiProcessinstanceCreateRequest
from dingtalk.api.rest.OapiChatNickBatchupdateRequest import OapiChatNickBatchupdateRequest
from dingtalk.api.rest.OapiEduCourseStartRequest import OapiEduCourseStartRequest
from dingtalk.api.rest.OapiEduGuardianCreateRequest import OapiEduGuardianCreateRequest
from dingtalk.api.rest.OapiImpaasGroupmemberModifymemberinfoRequest import OapiImpaasGroupmemberModifymemberinfoRequest
from dingtalk.api.rest.OapiWorkspaceTaskCreateRequest import OapiWorkspaceTaskCreateRequest
from dingtalk.api.rest.OapiEduCourseEndRequest import OapiEduCourseEndRequest
from dingtalk.api.rest.OapiMiniappAppinfoQueryRequest import OapiMiniappAppinfoQueryRequest
from dingtalk.api.rest.OapiFugongProcessCodeGetRequest import OapiFugongProcessCodeGetRequest
from dingtalk.api.rest.OapiAttendanceVacationRecordListRequest import OapiAttendanceVacationRecordListRequest
from dingtalk.api.rest.OapiOrgpaasOrgInfoGetRequest import OapiOrgpaasOrgInfoGetRequest
from dingtalk.api.rest.OapiAttendanceGroupDeleteRequest import OapiAttendanceGroupDeleteRequest
from dingtalk.api.rest.OapiChatbotPictureurlGetRequest import OapiChatbotPictureurlGetRequest
from dingtalk.api.rest.OapiEduGradeGetRequest import OapiEduGradeGetRequest
from dingtalk.api.rest.CorpChatbotListbychatbotidsRequest import CorpChatbotListbychatbotidsRequest
from dingtalk.api.rest.CorpHealthStepinfoListRequest import CorpHealthStepinfoListRequest
from dingtalk.api.rest.OapiProcessQuerypayrelatedtemplateRequest import OapiProcessQuerypayrelatedtemplateRequest
from dingtalk.api.rest.OapiOpenencryptEncryptboxStatusUpdateRequest import OapiOpenencryptEncryptboxStatusUpdateRequest
from dingtalk.api.rest.OapiRhinoMosSpaceDeviceCheckOutRequest import OapiRhinoMosSpaceDeviceCheckOutRequest
from dingtalk.api.rest.OapiAppstoreOrdersSpecialCanalUpdateOrderRequest import OapiAppstoreOrdersSpecialCanalUpdateOrderRequest
from dingtalk.api.rest.OapiCrmObjectdataCustomobjectUpdateRequest import OapiCrmObjectdataCustomobjectUpdateRequest
from dingtalk.api.rest.OapiDingmiO2oSendRequest import OapiDingmiO2oSendRequest
from dingtalk.api.rest.OapiEduCourseBatchcreateRequest import OapiEduCourseBatchcreateRequest
from dingtalk.api.rest.OapiServiceaccountListRequest import OapiServiceaccountListRequest
from dingtalk.api.rest.OapiAtsRpaResumeMailCollectRequest import OapiAtsRpaResumeMailCollectRequest
from dingtalk.api.rest.OapiAttendanceGroupModifyRequest import OapiAttendanceGroupModifyRequest
from dingtalk.api.rest.OapiRoleUpdateRoleRequest import OapiRoleUpdateRoleRequest
from dingtalk.api.rest.OapiDingpayOrderApplypayRequest import OapiDingpayOrderApplypayRequest
from dingtalk.api.rest.OapiServiceaccountMenuGetRequest import OapiServiceaccountMenuGetRequest
from dingtalk.api.rest.OapiAttendanceGetleavestatusRequest import OapiAttendanceGetleavestatusRequest
from dingtalk.api.rest.OapiMaterialNewsUpdateRequest import OapiMaterialNewsUpdateRequest
from dingtalk.api.rest.OapiV2DepartmentListparentbydeptRequest import OapiV2DepartmentListparentbydeptRequest
from dingtalk.api.rest.OapiServiceaccountUpdateRequest import OapiServiceaccountUpdateRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleListRequest import OapiAuthorizationRbacRoleListRequest
from dingtalk.api.rest.OapiAttendanceGroupPositionsRemoveRequest import OapiAttendanceGroupPositionsRemoveRequest
from dingtalk.api.rest.OapiPbpInstanceGroupPositionUpdateRequest import OapiPbpInstanceGroupPositionUpdateRequest
from dingtalk.api.rest.OapiAttendanceListRecordRequest import OapiAttendanceListRecordRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeAddpreentryRequest import OapiSmartworkHrmEmployeeAddpreentryRequest
from dingtalk.api.rest.OapiRhinoMosSpaceWorkerCheckOutRequest import OapiRhinoMosSpaceWorkerCheckOutRequest
from dingtalk.api.rest.OapiWorkspaceProjectCreateV2Request import OapiWorkspaceProjectCreateV2Request
from dingtalk.api.rest.OapiHireStatisticsBizflowListRequest import OapiHireStatisticsBizflowListRequest
from dingtalk.api.rest.OapiMicroappAddwithuseridRequest import OapiMicroappAddwithuseridRequest
from dingtalk.api.rest.OapiCardIntelligentEmpgroupSendRequest import OapiCardIntelligentEmpgroupSendRequest
from dingtalk.api.rest.OapiKacDatavMicroappDetailListRequest import OapiKacDatavMicroappDetailListRequest
from dingtalk.api.rest.OapiSmartdeviceApplyoutidRequest import OapiSmartdeviceApplyoutidRequest
from dingtalk.api.rest.OapiEduCourseJoinRequest import OapiEduCourseJoinRequest
from dingtalk.api.rest.SmartworkBpmsProcessinstanceListRequest import SmartworkBpmsProcessinstanceListRequest
from dingtalk.api.rest.OapiPbpEventSyncRequest import OapiPbpEventSyncRequest
from dingtalk.api.rest.OapiRobotMessageGetpushidRequest import OapiRobotMessageGetpushidRequest
from dingtalk.api.rest.OapiImpaasGroupQueryRequest import OapiImpaasGroupQueryRequest
from dingtalk.api.rest.OapiUserTokenGetRequest import OapiUserTokenGetRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeFieldGrouplistRequest import OapiSmartworkHrmEmployeeFieldGrouplistRequest
from dingtalk.api.rest.OapiAlitripBtripInvoiceSettingDeleteRequest import OapiAlitripBtripInvoiceSettingDeleteRequest
from dingtalk.api.rest.OapiRhinoMosExecTrackEntityconditionListRequest import OapiRhinoMosExecTrackEntityconditionListRequest
from dingtalk.api.rest.CorpExtcontactCreateRequest import CorpExtcontactCreateRequest
from dingtalk.api.rest.OapiAttendanceVacationQuotaListRequest import OapiAttendanceVacationQuotaListRequest
from dingtalk.api.rest.OapiMedalCorpmedalGrantRequest import OapiMedalCorpmedalGrantRequest
from dingtalk.api.rest.OapiAttendanceGroupMemberUpdateRequest import OapiAttendanceGroupMemberUpdateRequest
from dingtalk.api.rest.OapiDingtaxUserPushRequest import OapiDingtaxUserPushRequest
from dingtalk.api.rest.OapiProcessWorkrecordDeleteRequest import OapiProcessWorkrecordDeleteRequest
from dingtalk.api.rest.OapiAppstoreInternalUnfinishedorderListRequest import OapiAppstoreInternalUnfinishedorderListRequest
from dingtalk.api.rest.OapiImpaasGroupCreateRequest import OapiImpaasGroupCreateRequest
from dingtalk.api.rest.OapiProcessWorkrecordUpdateRequest import OapiProcessWorkrecordUpdateRequest
from dingtalk.api.rest.OapiOrgOpenencryptHeartbeatRequest import OapiOrgOpenencryptHeartbeatRequest
from dingtalk.api.rest.OapiProcessinstanceFileUploadRequest import OapiProcessinstanceFileUploadRequest
from dingtalk.api.rest.OapiChatUpdategroupnickRequest import OapiChatUpdategroupnickRequest
from dingtalk.api.rest.OapiCollectionFormCreateRequest import OapiCollectionFormCreateRequest
from dingtalk.api.rest.OapiEduClassconversationAsyncsendRequest import OapiEduClassconversationAsyncsendRequest
from dingtalk.api.rest.OapiImpaasConversationCreateRequest import OapiImpaasConversationCreateRequest
from dingtalk.api.rest.OapiRobotMessageSendgroupRequest import OapiRobotMessageSendgroupRequest
from dingtalk.api.rest.OapiDingtalkImpaasMessageCrossdomainSendRequest import OapiDingtalkImpaasMessageCrossdomainSendRequest
from dingtalk.api.rest.OapiEnterpriseMainorgTotaldataStatRequest import OapiEnterpriseMainorgTotaldataStatRequest
from dingtalk.api.rest.OapiAtsEvaluateJobmatchStartRequest import OapiAtsEvaluateJobmatchStartRequest
from dingtalk.api.rest.OapiSmartdeviceDeviceQuerylistRequest import OapiSmartdeviceDeviceQuerylistRequest
from dingtalk.api.rest.CorpSearchCorpcontactBaseinfoRequest import CorpSearchCorpcontactBaseinfoRequest
from dingtalk.api.rest.OapiRhinoMosExecPerformConditionalFinishRequest import OapiRhinoMosExecPerformConditionalFinishRequest
from dingtalk.api.rest.OapiAttendanceShiftSearchRequest import OapiAttendanceShiftSearchRequest
from dingtalk.api.rest.OapiSnsGettokenRequest import OapiSnsGettokenRequest
from dingtalk.api.rest.OapiBlackboardCreateRequest import OapiBlackboardCreateRequest
from dingtalk.api.rest.OapiUserSimplelistRequest import OapiUserSimplelistRequest
from dingtalk.api.rest.OapiEduHomeworkStudentTopicRecordRequest import OapiEduHomeworkStudentTopicRecordRequest
from dingtalk.api.rest.OapiProcessListbyuseridRequest import OapiProcessListbyuseridRequest
from dingtalk.api.rest.OapiIndustryStudentpoolBatchaddRequest import OapiIndustryStudentpoolBatchaddRequest
from dingtalk.api.rest.OapiCustomerserviceMessageSendRequest import OapiCustomerserviceMessageSendRequest
from dingtalk.api.rest.OapiServiceSetCorpIpwhitelistRequest import OapiServiceSetCorpIpwhitelistRequest
from dingtalk.api.rest.OapiImpaasConversationSendmessageRequest import OapiImpaasConversationSendmessageRequest
from dingtalk.api.rest.OapiV2SafeQuerystatusRequest import OapiV2SafeQuerystatusRequest
from dingtalk.api.rest.OapiRelationRemarkModifyRequest import OapiRelationRemarkModifyRequest
from dingtalk.api.rest.OapiPbpInstanceCreateRequest import OapiPbpInstanceCreateRequest
from dingtalk.api.rest.OapiCrmContactCreateRequest import OapiCrmContactCreateRequest
from dingtalk.api.rest.OapiAlitripBtripPriceQueryRequest import OapiAlitripBtripPriceQueryRequest
from dingtalk.api.rest.OapiProcessinstanceCspaceInfoRequest import OapiProcessinstanceCspaceInfoRequest
from dingtalk.api.rest.OapiAttendanceVacationQuotaInitRequest import OapiAttendanceVacationQuotaInitRequest
from dingtalk.api.rest.OapiMiniappAppversionQueryRequest import OapiMiniappAppversionQueryRequest
from dingtalk.api.rest.OapiCrmObjectdataCustomobjectCreateRequest import OapiCrmObjectdataCustomobjectCreateRequest
from dingtalk.api.rest.OapiMedalCorpmedalQueryRequest import OapiMedalCorpmedalQueryRequest
from dingtalk.api.rest.OapiFileUploadTransactionRequest import OapiFileUploadTransactionRequest
from dingtalk.api.rest.OapiEduSubjectDeleteRequest import OapiEduSubjectDeleteRequest
from dingtalk.api.rest.OapiKacDatavChatSummaryGetRequest import OapiKacDatavChatSummaryGetRequest
from dingtalk.api.rest.OapiMiniappPackageconfigQueryRequest import OapiMiniappPackageconfigQueryRequest
from dingtalk.api.rest.CorpLivenessGetRequest import CorpLivenessGetRequest
from dingtalk.api.rest.OapiAttendanceGroupDeletebyidRequest import OapiAttendanceGroupDeletebyidRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeFieldListRequest import OapiSmartworkHrmEmployeeFieldListRequest
from dingtalk.api.rest.OapiRhinoMosExecPerformCreateRequest import OapiRhinoMosExecPerformCreateRequest
from dingtalk.api.rest.OapiEduSubjectGetRequest import OapiEduSubjectGetRequest
from dingtalk.api.rest.OapiServiceaccountAddRequest import OapiServiceaccountAddRequest
from dingtalk.api.rest.OapiSmartdeviceFacegroupCreateRequest import OapiSmartdeviceFacegroupCreateRequest
from dingtalk.api.rest.OapiImpaasUserGetlogintokenRequest import OapiImpaasUserGetlogintokenRequest
from dingtalk.api.rest.OapiAlitripBtripProjectAddRequest import OapiAlitripBtripProjectAddRequest
from dingtalk.api.rest.OapiCcoserviceEntranceSendnotifyRequest import OapiCcoserviceEntranceSendnotifyRequest
from dingtalk.api.rest.OapiServiceGetSuiteTokenRequest import OapiServiceGetSuiteTokenRequest
from dingtalk.api.rest.OapiKacDatavDeptVideoliveListRequest import OapiKacDatavDeptVideoliveListRequest
from dingtalk.api.rest.SmartworkAttendsGetusergroupRequest import SmartworkAttendsGetusergroupRequest
from dingtalk.api.rest.CcoserviceServicegroupAddmemberRequest import CcoserviceServicegroupAddmemberRequest
from dingtalk.api.rest.OapiAttendanceGroupWifisRemoveRequest import OapiAttendanceGroupWifisRemoveRequest
from dingtalk.api.rest.OapiAlitripBtripInvoiceSettingAddRequest import OapiAlitripBtripInvoiceSettingAddRequest
from dingtalk.api.rest.OapiCalendarCreateRequest import OapiCalendarCreateRequest
from dingtalk.api.rest.OapiSmartdeviceAtmachineUserUpdateRequest import OapiSmartdeviceAtmachineUserUpdateRequest
from dingtalk.api.rest.OapiAttendanceGroupMinimalismListRequest import OapiAttendanceGroupMinimalismListRequest
from dingtalk.api.rest.OapiCrmObjectdataContactDeleteRequest import OapiCrmObjectdataContactDeleteRequest
from dingtalk.api.rest.OapiEnterpriseSuborgTotaldataStatRequest import OapiEnterpriseSuborgTotaldataStatRequest
from dingtalk.api.rest.OapiChatQrcodeGetRequest import OapiChatQrcodeGetRequest
from dingtalk.api.rest.OapiAppstoreOrdersSpecialCanalCreateOrderRequest import OapiAppstoreOrdersSpecialCanalCreateOrderRequest
from dingtalk.api.rest.OapiCallGetuserlistRequest import OapiCallGetuserlistRequest
from dingtalk.api.rest.OapiMaterialNewsListRequest import OapiMaterialNewsListRequest
from dingtalk.api.rest.CorpEmpSearchRequest import CorpEmpSearchRequest
from dingtalk.api.rest.OapiAlitripBtripReimbursementAppstatusSyncRequest import OapiAlitripBtripReimbursementAppstatusSyncRequest
from dingtalk.api.rest.OapiProcessinstanceListRequest import OapiProcessinstanceListRequest
from dingtalk.api.rest.OapiCspaceAddRequest import OapiCspaceAddRequest
from dingtalk.api.rest.OapiFinanceAlipayAccountGetbyuidRequest import OapiFinanceAlipayAccountGetbyuidRequest
from dingtalk.api.rest.CorpHealthStepinfoGetuserstatusRequest import CorpHealthStepinfoGetuserstatusRequest
from dingtalk.api.rest.OapiEduStudentAttendanceStatisticsGetRequest import OapiEduStudentAttendanceStatisticsGetRequest
from dingtalk.api.rest.OapiSmartdeviceFacegroupUpdateRequest import OapiSmartdeviceFacegroupUpdateRequest
from dingtalk.api.rest.OapiRhinoHumanresProductionteamQueryRequest import OapiRhinoHumanresProductionteamQueryRequest
from dingtalk.api.rest.OapiV2DepartmentUpdateRequest import OapiV2DepartmentUpdateRequest
from dingtalk.api.rest.OapiXiaoqianApiTestRequest import OapiXiaoqianApiTestRequest
from dingtalk.api.rest.OapiRoleRemoverolesforempsRequest import OapiRoleRemoverolesforempsRequest
from dingtalk.api.rest.OapiBlackboardCategoryListRequest import OapiBlackboardCategoryListRequest
from dingtalk.api.rest.OapiAttendanceCorpInviteactiveAddRequest import OapiAttendanceCorpInviteactiveAddRequest
from dingtalk.api.rest.OapiMaterialNewsGetRequest import OapiMaterialNewsGetRequest
from dingtalk.api.rest.OapiEduHomeworkStudentCommentUpdateRequest import OapiEduHomeworkStudentCommentUpdateRequest
from dingtalk.api.rest.CorpDeviceManageUnbindRequest import CorpDeviceManageUnbindRequest
from dingtalk.api.rest.OapiAttendanceTestGetclassRequest import OapiAttendanceTestGetclassRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeQueryonjobRequest import OapiSmartworkHrmEmployeeQueryonjobRequest
from dingtalk.api.rest.OapiFinanceFaceVerificationUpdateRequest import OapiFinanceFaceVerificationUpdateRequest
from dingtalk.api.rest.OapiV2DepartmentListsubidRequest import OapiV2DepartmentListsubidRequest
from dingtalk.api.rest.OapiAttendanceVacationTypeListRequest import OapiAttendanceVacationTypeListRequest
from dingtalk.api.rest.OapiAtsCandidateGetRequest import OapiAtsCandidateGetRequest
from dingtalk.api.rest.OapiSmartdeviceFacelevelGetRequest import OapiSmartdeviceFacelevelGetRequest
from dingtalk.api.rest.OapiDingmiRobotPushRequest import OapiDingmiRobotPushRequest
from dingtalk.api.rest.OapiAlitripBtripApprovalUpdateRequest import OapiAlitripBtripApprovalUpdateRequest
from dingtalk.api.rest.OapiEduFaceSearchRequest import OapiEduFaceSearchRequest
from dingtalk.api.rest.OapiCalendarV2EventDetailRequest import OapiCalendarV2EventDetailRequest
from dingtalk.api.rest.OapiServiceReauthCorpRequest import OapiServiceReauthCorpRequest
from dingtalk.api.rest.OapiUserBatchdeleteRequest import OapiUserBatchdeleteRequest
from dingtalk.api.rest.OapiRetailSellerOrgdetailQueryRequest import OapiRetailSellerOrgdetailQueryRequest
from dingtalk.api.rest.OapiAttendanceGroupWifisQueryRequest import OapiAttendanceGroupWifisQueryRequest
from dingtalk.api.rest.OapiUserCorpinfoListRequest import OapiUserCorpinfoListRequest
from dingtalk.api.rest.OapiEduHomeworkGroupRoleGetRequest import OapiEduHomeworkGroupRoleGetRequest
from dingtalk.api.rest.OapiConferenceParticipantAddRequest import OapiConferenceParticipantAddRequest
from dingtalk.api.rest.OapiMaterialNewsAddRequest import OapiMaterialNewsAddRequest
from dingtalk.api.rest.OapiProcessinstanceListidsRequest import OapiProcessinstanceListidsRequest
from dingtalk.api.rest.OapiFinanceLoanNotifyCreditRequest import OapiFinanceLoanNotifyCreditRequest
from dingtalk.api.rest.OapiRobotMessageStatisticsListbyconversationidRequest import OapiRobotMessageStatisticsListbyconversationidRequest
from dingtalk.api.rest.OapiReportListRequest import OapiReportListRequest
from dingtalk.api.rest.OapiEduHomeworkStudentCommentDeleteRequest import OapiEduHomeworkStudentCommentDeleteRequest
from dingtalk.api.rest.OapiRoleVisibleSetRequest import OapiRoleVisibleSetRequest
from dingtalk.api.rest.CorpReportListRequest import CorpReportListRequest
from dingtalk.api.rest.OapiRobotMessageStatisticsListbypushidRequest import OapiRobotMessageStatisticsListbypushidRequest
from dingtalk.api.rest.OapiMicroappUpdateRequest import OapiMicroappUpdateRequest
from dingtalk.api.rest.CorpDeviceManageQuerylistRequest import CorpDeviceManageQuerylistRequest
from dingtalk.api.rest.OapiCspaceAuditlogListRequest import OapiCspaceAuditlogListRequest
from dingtalk.api.rest.OapiSceneservicegroupMessageSendRequest import OapiSceneservicegroupMessageSendRequest
from dingtalk.api.rest.OapiChatThemeUpdateRequest import OapiChatThemeUpdateRequest
from dingtalk.api.rest.OapiAttendanceGroupScheduleClearRequest import OapiAttendanceGroupScheduleClearRequest
from dingtalk.api.rest.OapiRetailUserTokenGenerateRequest import OapiRetailUserTokenGenerateRequest
from dingtalk.api.rest.OapiImChatScenegroupMemberAddRequest import OapiImChatScenegroupMemberAddRequest
from dingtalk.api.rest.OapiTrainingGroupinfoGetRequest import OapiTrainingGroupinfoGetRequest
from dingtalk.api.rest.OapiBlackboardListidsRequest import OapiBlackboardListidsRequest
from dingtalk.api.rest.OapiConnectorOpenRequest import OapiConnectorOpenRequest
from dingtalk.api.rest.OapiServiceGetPermanentCodeRequest import OapiServiceGetPermanentCodeRequest
from dingtalk.api.rest.OapiUserGetOrgUserCountRequest import OapiUserGetOrgUserCountRequest
from dingtalk.api.rest.CorpExtcontactUpdateRequest import CorpExtcontactUpdateRequest
from dingtalk.api.rest.OapiContactRolevisibilityUpdateRequest import OapiContactRolevisibilityUpdateRequest
from dingtalk.api.rest.OapiCalendarV2EventCancelRequest import OapiCalendarV2EventCancelRequest
from dingtalk.api.rest.OapiEduFamilyChildGetRequest import OapiEduFamilyChildGetRequest
from dingtalk.api.rest.OapiHireAuthRoleGetbyuserRequest import OapiHireAuthRoleGetbyuserRequest
from dingtalk.api.rest.OapiAttendanceVacationTypeDeleteRequest import OapiAttendanceVacationTypeDeleteRequest
from dingtalk.api.rest.OapiCrmOrgVirtualcorpidGetRequest import OapiCrmOrgVirtualcorpidGetRequest
from dingtalk.api.rest.OapiAttendanceGetleaveapprovedurationRequest import OapiAttendanceGetleaveapprovedurationRequest
from dingtalk.api.rest.OapiImpaasMessageAsyncsendRequest import OapiImpaasMessageAsyncsendRequest
from dingtalk.api.rest.CorpRoleAddrolesforempsRequest import CorpRoleAddrolesforempsRequest
from dingtalk.api.rest.OapiReportCommentListRequest import OapiReportCommentListRequest
from dingtalk.api.rest.OapiImpaasNewretailSendstaffmessageRequest import OapiImpaasNewretailSendstaffmessageRequest
from dingtalk.api.rest.OapiServiceGetAuthInfoRequest import OapiServiceGetAuthInfoRequest
from dingtalk.api.rest.OapiServiceGetCorpTokenRequest import OapiServiceGetCorpTokenRequest
from dingtalk.api.rest.OapiChatMessageRecallRequest import OapiChatMessageRecallRequest
from dingtalk.api.rest.OapiLivePlaybackRequest import OapiLivePlaybackRequest
from dingtalk.api.rest.OapiDepartmentGetRequest import OapiDepartmentGetRequest
from dingtalk.api.rest.OapiSmartworkHrmRosterMetaGetRequest import OapiSmartworkHrmRosterMetaGetRequest
from dingtalk.api.rest.OapiMcsConferenceCreateRequest import OapiMcsConferenceCreateRequest
from dingtalk.api.rest.OapiLiveGroupliveSharelistRequest import OapiLiveGroupliveSharelistRequest
from dingtalk.api.rest.OapiMessageSendToSingleConversationRequest import OapiMessageSendToSingleConversationRequest
from dingtalk.api.rest.OapiEduClassStudentGetRequest import OapiEduClassStudentGetRequest
from dingtalk.api.rest.OapiPlanetomFeedsWatchdataGetRequest import OapiPlanetomFeedsWatchdataGetRequest
from dingtalk.api.rest.OapiAttendanceGroupPositionsAddRequest import OapiAttendanceGroupPositionsAddRequest
from dingtalk.api.rest.OapiFileUploadSingleRequest import OapiFileUploadSingleRequest
from dingtalk.api.rest.OapiKacDatavVideoliveGetRequest import OapiKacDatavVideoliveGetRequest
from dingtalk.api.rest.OapiAttendanceScheduleResultListbyidsRequest import OapiAttendanceScheduleResultListbyidsRequest
from dingtalk.api.rest.OapiProcessWorkrecordBatchupdateRequest import OapiProcessWorkrecordBatchupdateRequest
from dingtalk.api.rest.OapiAlitripBtripCostCenterEntitySetRequest import OapiAlitripBtripCostCenterEntitySetRequest
from dingtalk.api.rest.OapiRhinoMosSpaceDeviceCheckInListRequest import OapiRhinoMosSpaceDeviceCheckInListRequest
from dingtalk.api.rest.OapiUserListRequest import OapiUserListRequest
from dingtalk.api.rest.CorpConversationCorpconversionListmemberRequest import CorpConversationCorpconversionListmemberRequest
from dingtalk.api.rest.OapiImChatbotDeleteRequest import OapiImChatbotDeleteRequest
from dingtalk.api.rest.OapiAttendanceShiftHistoryQueryRequest import OapiAttendanceShiftHistoryQueryRequest
from dingtalk.api.rest.OapiCallCalluserRequest import OapiCallCalluserRequest
from dingtalk.api.rest.OapiLiveGroupliveDetailGetRequest import OapiLiveGroupliveDetailGetRequest
from dingtalk.api.rest.OapiAlitripBtripCostCenterNewRequest import OapiAlitripBtripCostCenterNewRequest
from dingtalk.api.rest.OapiAttendanceGroupScheduleAsyncRequest import OapiAttendanceGroupScheduleAsyncRequest
from dingtalk.api.rest.OapiAlitripBtripApprovalModifyRequest import OapiAlitripBtripApprovalModifyRequest
from dingtalk.api.rest.OapiLiveGroupliveListRequest import OapiLiveGroupliveListRequest
from dingtalk.api.rest.OapiAttendanceGetattcolumnsRequest import OapiAttendanceGetattcolumnsRequest
from dingtalk.api.rest.OapiEduSubDataGetRequest import OapiEduSubDataGetRequest
from dingtalk.api.rest.OapiAttendanceApproveCancelRequest import OapiAttendanceApproveCancelRequest
from dingtalk.api.rest.OapiKacDatavVideoconfDetailListRequest import OapiKacDatavVideoconfDetailListRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeListRequest import OapiSmartworkHrmEmployeeListRequest
from dingtalk.api.rest.OapiWorkspaceProjectNoticeSendRequest import OapiWorkspaceProjectNoticeSendRequest
from dingtalk.api.rest.SmartworkBpmsProcessGetbybiztypeRequest import SmartworkBpmsProcessGetbybiztypeRequest
from dingtalk.api.rest.OapiFaceauthGetRequest import OapiFaceauthGetRequest
from dingtalk.api.rest.OapiConferenceParticipantDeleteRequest import OapiConferenceParticipantDeleteRequest
from dingtalk.api.rest.OapiUserCanAccessMicroappRequest import OapiUserCanAccessMicroappRequest
from dingtalk.api.rest.OapiImpaasGroupmemberGetmemberlistRequest import OapiImpaasGroupmemberGetmemberlistRequest
from dingtalk.api.rest.OapiWorkspaceProjectMemberAddRequest import OapiWorkspaceProjectMemberAddRequest
from dingtalk.api.rest.OapiCustomerserviceTicketCreateRequest import OapiCustomerserviceTicketCreateRequest
from dingtalk.api.rest.OapiAlitripBtripCostCenterTransferRequest import OapiAlitripBtripCostCenterTransferRequest
from dingtalk.api.rest.OapiMpdevAccesskeyGetRequest import OapiMpdevAccesskeyGetRequest
from dingtalk.api.rest.CorpMessageCorpconversationGetsendprogressRequest import CorpMessageCorpconversationGetsendprogressRequest
from dingtalk.api.rest.OapiWikiGroupPublicListRequest import OapiWikiGroupPublicListRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeQuerydimissionRequest import OapiSmartworkHrmEmployeeQuerydimissionRequest
from dingtalk.api.rest.OapiCalendarListRequest import OapiCalendarListRequest
from dingtalk.api.rest.OapiCrmObjectdataFollowrecordQueryRequest import OapiCrmObjectdataFollowrecordQueryRequest
from dingtalk.api.rest.OapiImpaasUserSubaccountAddRequest import OapiImpaasUserSubaccountAddRequest
from dingtalk.api.rest.OapiServiceGetAgentRequest import OapiServiceGetAgentRequest
from dingtalk.api.rest.OapiEnterpriseFamilydrListRequest import OapiEnterpriseFamilydrListRequest
from dingtalk.api.rest.OapiCustomerserviceActivityExecuteRequest import OapiCustomerserviceActivityExecuteRequest
from dingtalk.api.rest.OapiAttendanceGroupUpdateRequest import OapiAttendanceGroupUpdateRequest
from dingtalk.api.rest.OapiProcessDentryAuthRequest import OapiProcessDentryAuthRequest
from dingtalk.api.rest.OapiDepartmentUpdateRequest import OapiDepartmentUpdateRequest
from dingtalk.api.rest.OapiOrgOpenencryptAuthappcloseRequest import OapiOrgOpenencryptAuthappcloseRequest
from dingtalk.api.rest.OapiCustomerserviceStatusGetRequest import OapiCustomerserviceStatusGetRequest
from dingtalk.api.rest.OapiAttendanceShiftUpdatepunchesRequest import OapiAttendanceShiftUpdatepunchesRequest
from dingtalk.api.rest.OapiEduHomeworkTopicCreateRequest import OapiEduHomeworkTopicCreateRequest
from dingtalk.api.rest.OapiAttendanceAdvancedServiceBindRequest import OapiAttendanceAdvancedServiceBindRequest
from dingtalk.api.rest.CorpDeviceNickUpdateRequest import CorpDeviceNickUpdateRequest
from dingtalk.api.rest.OapiImpaasNewretailSendstaffgroupmessageRequest import OapiImpaasNewretailSendstaffgroupmessageRequest
from dingtalk.api.rest.OapiAttendanceGetcolumnvalRequest import OapiAttendanceGetcolumnvalRequest
from dingtalk.api.rest.OapiSnsGetuserinfoRequest import OapiSnsGetuserinfoRequest
from dingtalk.api.rest.OapiProcessFormConditionListRequest import OapiProcessFormConditionListRequest
from dingtalk.api.rest.OapiSmartdeviceDeviceUpdatenickRequest import OapiSmartdeviceDeviceUpdatenickRequest
from dingtalk.api.rest.OapiEduUseridGetRequest import OapiEduUseridGetRequest
from dingtalk.api.rest.OapiAttendanceShiftListRequest import OapiAttendanceShiftListRequest
from dingtalk.api.rest.OapiSmartdeviceVisitorRemovevisitorRequest import OapiSmartdeviceVisitorRemovevisitorRequest
from dingtalk.api.rest.OapiEduUserRelationListRequest import OapiEduUserRelationListRequest
from dingtalk.api.rest.OapiKacDatavDeptDingListRequest import OapiKacDatavDeptDingListRequest
from dingtalk.api.rest.OapiProjectPointRuleListRequest import OapiProjectPointRuleListRequest
from dingtalk.api.rest.OapiAttendanceGetusergroupRequest import OapiAttendanceGetusergroupRequest
from dingtalk.api.rest.OapiSsoGettokenRequest import OapiSsoGettokenRequest
from dingtalk.api.rest.OapiRobotMessageGrouptaskQueryRequest import OapiRobotMessageGrouptaskQueryRequest
from dingtalk.api.rest.OapiMessageSendToConversationRequest import OapiMessageSendToConversationRequest
from dingtalk.api.rest.OapiEduCourseReplayRequest import OapiEduCourseReplayRequest
from dingtalk.api.rest.OapiProcessinstanceExecuteRequest import OapiProcessinstanceExecuteRequest
from dingtalk.api.rest.OapiStatisticsDetailsRequest import OapiStatisticsDetailsRequest
from dingtalk.api.rest.OapiLiveQueryRequest import OapiLiveQueryRequest
from dingtalk.api.rest.OapiRetailUserTokenCheckRequest import OapiRetailUserTokenCheckRequest
from dingtalk.api.rest.OapiAlitripBtripCostCenterEntityAddRequest import OapiAlitripBtripCostCenterEntityAddRequest
from dingtalk.api.rest.OapiContactRolevisibilityDeleteRequest import OapiContactRolevisibilityDeleteRequest
from dingtalk.api.rest.OapiProcessWorkrecordTaskUpdateRequest import OapiProcessWorkrecordTaskUpdateRequest
from dingtalk.api.rest.OapiEduGuardianGetRequest import OapiEduGuardianGetRequest
from dingtalk.api.rest.CorpChatbotCreateorgbotRequest import CorpChatbotCreateorgbotRequest
from dingtalk.api.rest.OapiImChatScenegroupTemplateCloseRequest import OapiImChatScenegroupTemplateCloseRequest
from dingtalk.api.rest.OapiRhinoMosLayoutOperationdefsSectionlastRequest import OapiRhinoMosLayoutOperationdefsSectionlastRequest
from dingtalk.api.rest.CorpRoleGetrolegroupRequest import CorpRoleGetrolegroupRequest
from dingtalk.api.rest.OapiProcessGetByNameRequest import OapiProcessGetByNameRequest
from dingtalk.api.rest.OapiProcessInstanceTerminateRequest import OapiProcessInstanceTerminateRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleRemoveRequest import OapiAuthorizationRbacRoleRemoveRequest
from dingtalk.api.rest.OapiDepartmentDeleteRequest import OapiDepartmentDeleteRequest
from dingtalk.api.rest.OapiProcessinstanceCspacePreviewRequest import OapiProcessinstanceCspacePreviewRequest
from dingtalk.api.rest.OapiPlanetomFeedsStatisticGetRequest import OapiPlanetomFeedsStatisticGetRequest
from dingtalk.api.rest.OapiChatMemberFriendswitchUpdateRequest import OapiChatMemberFriendswitchUpdateRequest
from dingtalk.api.rest.OapiCrmObjectmetaFollowrecordDescribeRequest import OapiCrmObjectmetaFollowrecordDescribeRequest
from dingtalk.api.rest.OapiRoleGetrolegroupRequest import OapiRoleGetrolegroupRequest
from dingtalk.api.rest.OapiRetailUserBindapplyRequest import OapiRetailUserBindapplyRequest
from dingtalk.api.rest.OapiWorkbenchShortcutListbypagingRequest import OapiWorkbenchShortcutListbypagingRequest
from dingtalk.api.rest.OapiMicroappDeleteRequest import OapiMicroappDeleteRequest
from dingtalk.api.rest.OapiMiniappDeploypackageQueryRequest import OapiMiniappDeploypackageQueryRequest
from dingtalk.api.rest.OapiAtsJobGetRequest import OapiAtsJobGetRequest
from dingtalk.api.rest.OapiChatbotMessageSendRequest import OapiChatbotMessageSendRequest
from dingtalk.api.rest.OapiEduCardTaskTodayListRequest import OapiEduCardTaskTodayListRequest
from dingtalk.api.rest.OapiAttendanceGroupGetRequest import OapiAttendanceGroupGetRequest
from dingtalk.api.rest.OapiDingpayBillQuerytagRequest import OapiDingpayBillQuerytagRequest
from dingtalk.api.rest.OapiAtsMessageCorpSystemaccountSendRequest import OapiAtsMessageCorpSystemaccountSendRequest
from dingtalk.api.rest.OapiMaterialArticlePublishRequest import OapiMaterialArticlePublishRequest
from dingtalk.api.rest.OapiMpdevBuildCreateRequest import OapiMpdevBuildCreateRequest
from dingtalk.api.rest.OapiEduStudentCreateRequest import OapiEduStudentCreateRequest
from dingtalk.api.rest.OapiAttendanceApproveCheckRequest import OapiAttendanceApproveCheckRequest
from dingtalk.api.rest.OapiEduHomeworkUserRoleQueryRequest import OapiEduHomeworkUserRoleQueryRequest
from dingtalk.api.rest.OapiHireNavigationGetRequest import OapiHireNavigationGetRequest
from dingtalk.api.rest.OapiProjectInviteDataQueryRequest import OapiProjectInviteDataQueryRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesConditionGetRequest import OapiRhinoMosExecClothesConditionGetRequest
from dingtalk.api.rest.OapiSmartdeviceFacegroupMemberUpdateRequest import OapiSmartdeviceFacegroupMemberUpdateRequest
from dingtalk.api.rest.OapiWikiDocPublicListRequest import OapiWikiDocPublicListRequest
from dingtalk.api.rest.OapiReportStatisticsListbytypeRequest import OapiReportStatisticsListbytypeRequest
from dingtalk.api.rest.OapiEduHomeworkUserCourseQueryRequest import OapiEduHomeworkUserCourseQueryRequest
from dingtalk.api.rest.OapiEduRecommendReturnRequest import OapiEduRecommendReturnRequest
from dingtalk.api.rest.OapiAtsStatisticsJobListRequest import OapiAtsStatisticsJobListRequest
from dingtalk.api.rest.OapiRobotMessageSendorggroupRequest import OapiRobotMessageSendorggroupRequest
from dingtalk.api.rest.OapiEduCourseCreateRequest import OapiEduCourseCreateRequest
from dingtalk.api.rest.IsvCallRemoveuserlistRequest import IsvCallRemoveuserlistRequest
from dingtalk.api.rest.OapiCcoserviceServicegroupIsignoreproblemcheckRequest import OapiCcoserviceServicegroupIsignoreproblemcheckRequest
from dingtalk.api.rest.OapiWikiGroupListRequest import OapiWikiGroupListRequest
from dingtalk.api.rest.OapiRoleGetroleRequest import OapiRoleGetroleRequest
from dingtalk.api.rest.OapiAppstoreInternalOrderFinishRequest import OapiAppstoreInternalOrderFinishRequest
from dingtalk.api.rest.OapiWorkbenchShortcutGetguideuriRequest import OapiWorkbenchShortcutGetguideuriRequest
from dingtalk.api.rest.OapiAtsPluginDataPushRequest import OapiAtsPluginDataPushRequest
from dingtalk.api.rest.OapiCollectionFormGetRequest import OapiCollectionFormGetRequest
from dingtalk.api.rest.OapiWorkrecordAddRequest import OapiWorkrecordAddRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleActionUpdateRequest import OapiAuthorizationRbacRoleActionUpdateRequest
from dingtalk.api.rest.OapiEduSubjectMetadataListRequest import OapiEduSubjectMetadataListRequest
from dingtalk.api.rest.OapiExtcontactCreateRequest import OapiExtcontactCreateRequest
from dingtalk.api.rest.OapiDingTaskStatusUpdateRequest import OapiDingTaskStatusUpdateRequest
from dingtalk.api.rest.OapiImpaasConverstionCreateo2oRequest import OapiImpaasConverstionCreateo2oRequest
from dingtalk.api.rest.OapiAtsPluginStatisticsJobListRequest import OapiAtsPluginStatisticsJobListRequest
from dingtalk.api.rest.OapiKacDatavDeptDauListRequest import OapiKacDatavDeptDauListRequest
from dingtalk.api.rest.OapiAlitripBtripUnbindTaobaoRequest import OapiAlitripBtripUnbindTaobaoRequest
from dingtalk.api.rest.OapiHirePluginStatisticsBizflowListRequest import OapiHirePluginStatisticsBizflowListRequest
from dingtalk.api.rest.OapiCustomerserviceMemberGetRequest import OapiCustomerserviceMemberGetRequest
from dingtalk.api.rest.OapiImpaasGroupDismissRequest import OapiImpaasGroupDismissRequest
from dingtalk.api.rest.OapiWorkspaceTaskGetbysourceidRequest import OapiWorkspaceTaskGetbysourceidRequest
from dingtalk.api.rest.OapiProcessinstanceFileUrlGetRequest import OapiProcessinstanceFileUrlGetRequest
from dingtalk.api.rest.OapiRoleVisibleDeleteRequest import OapiRoleVisibleDeleteRequest
from dingtalk.api.rest.OapiEduHomeworkStudentMarkTagRequest import OapiEduHomeworkStudentMarkTagRequest
from dingtalk.api.rest.OapiEduRecommendCreateRequest import OapiEduRecommendCreateRequest
from dingtalk.api.rest.OapiAttendanceScheduleListbyusersRequest import OapiAttendanceScheduleListbyusersRequest
from dingtalk.api.rest.OapiMpdevPreviewbuildStatusGetRequest import OapiMpdevPreviewbuildStatusGetRequest
from dingtalk.api.rest.OapiImpaasOtoconversationCreateRequest import OapiImpaasOtoconversationCreateRequest
from dingtalk.api.rest.OapiAttendanceAdvancedServiceIsboundRequest import OapiAttendanceAdvancedServiceIsboundRequest
from dingtalk.api.rest.OapiIndustryOrganizationGetRequest import OapiIndustryOrganizationGetRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesUnfinishRequest import OapiRhinoMosExecClothesUnfinishRequest
from dingtalk.api.rest.OapiRetailUserUnionidqueryRequest import OapiRetailUserUnionidqueryRequest
from dingtalk.api.rest.OapiAlitripBtripCategoryAddressGetRequest import OapiAlitripBtripCategoryAddressGetRequest
from dingtalk.api.rest.OapiSmartdeviceMeetingroomCheckinRequest import OapiSmartdeviceMeetingroomCheckinRequest
from dingtalk.api.rest.OapiSnsConversationMemberListRequest import OapiSnsConversationMemberListRequest
from dingtalk.api.rest.OapiFugongHealthDataListRequest import OapiFugongHealthDataListRequest
from dingtalk.api.rest.OapiWorkspaceTaskUpdateRequest import OapiWorkspaceTaskUpdateRequest
from dingtalk.api.rest.OapiFinanceFaceVerificationInitRequest import OapiFinanceFaceVerificationInitRequest
from dingtalk.api.rest.OapiLiveCreateRequest import OapiLiveCreateRequest
from dingtalk.api.rest.OapiImpaasMessageGetmessageRequest import OapiImpaasMessageGetmessageRequest
from dingtalk.api.rest.OapiDingpayBillBatchqueryRequest import OapiDingpayBillBatchqueryRequest
from dingtalk.api.rest.OapiAlitripBtripVehicleOrderSearchRequest import OapiAlitripBtripVehicleOrderSearchRequest
from dingtalk.api.rest.IsvCallCalluserRequest import IsvCallCalluserRequest
from dingtalk.api.rest.OapiEduGroupMsgSendRequest import OapiEduGroupMsgSendRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeOnjoblistQueryRequest import OapiSmartworkHrmEmployeeOnjoblistQueryRequest
from dingtalk.api.rest.OapiDepartmentListParentDeptsByDeptRequest import OapiDepartmentListParentDeptsByDeptRequest
from dingtalk.api.rest.OapiEduClassCreateRequest import OapiEduClassCreateRequest
from dingtalk.api.rest.OapiEduSchoolInitRequest import OapiEduSchoolInitRequest
from dingtalk.api.rest.OapiCorpConversationMemberListRequest import OapiCorpConversationMemberListRequest
from dingtalk.api.rest.OapiCalendarV2AttendeeUpdateRequest import OapiCalendarV2AttendeeUpdateRequest
from dingtalk.api.rest.OapiAlitripBtripCostCenterEntityDeleteRequest import OapiAlitripBtripCostCenterEntityDeleteRequest
from dingtalk.api.rest.OapiEduHomeworkUpdateRequest import OapiEduHomeworkUpdateRequest
from dingtalk.api.rest.CorpExtcontactListlabelgroupsRequest import CorpExtcontactListlabelgroupsRequest
from dingtalk.api.rest.OapiEduCourseParticipantAddRequest import OapiEduCourseParticipantAddRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesIdListbypageRequest import OapiRhinoMosExecClothesIdListbypageRequest
from dingtalk.api.rest.OapiAlitripBtripInvoiceSearchRequest import OapiAlitripBtripInvoiceSearchRequest
from dingtalk.api.rest.OapiCrmObjectdataContactQueryRequest import OapiCrmObjectdataContactQueryRequest
from dingtalk.api.rest.OapiAttendanceGroupAddRequest import OapiAttendanceGroupAddRequest
from dingtalk.api.rest.OapiAttendanceGroupsQueryRequest import OapiAttendanceGroupsQueryRequest
from dingtalk.api.rest.OapiCspaceAuthCancelRequest import OapiCspaceAuthCancelRequest
from dingtalk.api.rest.OapiWorkspaceUpdateRequest import OapiWorkspaceUpdateRequest
from dingtalk.api.rest.OapiRobotMessageSendotoRequest import OapiRobotMessageSendotoRequest
from dingtalk.api.rest.OapiSmartdeviceDevicememberSyncRequest import OapiSmartdeviceDevicememberSyncRequest
from dingtalk.api.rest.OapiAttendanceApproveFinishRequest import OapiAttendanceApproveFinishRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeUpdateRequest import OapiSmartworkHrmEmployeeUpdateRequest
from dingtalk.api.rest.OapiPbpInstanceGroupPositionListRequest import OapiPbpInstanceGroupPositionListRequest
from dingtalk.api.rest.OapiMedalCorpmedalRemoveRequest import OapiMedalCorpmedalRemoveRequest
from dingtalk.api.rest.OapiSnsSendMsgRequest import OapiSnsSendMsgRequest
from dingtalk.api.rest.OapiProcessSyncRequest import OapiProcessSyncRequest
from dingtalk.api.rest.OapiDingmiCommonO2oPushRequest import OapiDingmiCommonO2oPushRequest
from dingtalk.api.rest.OapiAttendanceRecordUploadRequest import OapiAttendanceRecordUploadRequest
from dingtalk.api.rest.OapiRhinoMosSpaceWorkstationUpsertRequest import OapiRhinoMosSpaceWorkstationUpsertRequest
from dingtalk.api.rest.OapiKacDatavVideoliveViewerListRequest import OapiKacDatavVideoliveViewerListRequest
from dingtalk.api.rest.OapiEduTeacherGetRequest import OapiEduTeacherGetRequest
from dingtalk.api.rest.OapiRhinoMosExecTrackTrackconditionListRequest import OapiRhinoMosExecTrackTrackconditionListRequest
from dingtalk.api.rest.OapiWorkspaceTaskCleanRequest import OapiWorkspaceTaskCleanRequest
from dingtalk.api.rest.OapiUserAssociatedUnionidTransferRequest import OapiUserAssociatedUnionidTransferRequest
from dingtalk.api.rest.OapiImpaasGroupmemberModifyRequest import OapiImpaasGroupmemberModifyRequest
from dingtalk.api.rest.SmartworkBpmsProcessGetvisibleRequest import SmartworkBpmsProcessGetvisibleRequest
from dingtalk.api.rest.OapiConferenceUnpublishRequest import OapiConferenceUnpublishRequest
from dingtalk.api.rest.OapiRoleScopeUpdateRequest import OapiRoleScopeUpdateRequest
from dingtalk.api.rest.OapiEnterpriseSubareaTotaldataStatRequest import OapiEnterpriseSubareaTotaldataStatRequest
from dingtalk.api.rest.OapiSmartworkHrmMasterdataSaveRequest import OapiSmartworkHrmMasterdataSaveRequest
from dingtalk.api.rest.OapiCollectionFormListRequest import OapiCollectionFormListRequest
from dingtalk.api.rest.OapiCrmObjectdataListRequest import OapiCrmObjectdataListRequest
from dingtalk.api.rest.OapiHrmEmployeeDelandhandoverRequest import OapiHrmEmployeeDelandhandoverRequest
from dingtalk.api.rest.OapiCcoserviceServicegroupUpdateservicetimeRequest import OapiCcoserviceServicegroupUpdateservicetimeRequest
from dingtalk.api.rest.OapiAttendanceGroupMemberListRequest import OapiAttendanceGroupMemberListRequest
from dingtalk.api.rest.OapiProcessSaveRequest import OapiProcessSaveRequest
from dingtalk.api.rest.OapiEduCardTaskSubmitRequest import OapiEduCardTaskSubmitRequest
from dingtalk.api.rest.OapiIsvOpenencryptRegistekmsRequest import OapiIsvOpenencryptRegistekmsRequest
from dingtalk.api.rest.OapiImChatScenegroupMemberDeleteRequest import OapiImChatScenegroupMemberDeleteRequest
from dingtalk.api.rest.OapiSnsGetSnsTokenRequest import OapiSnsGetSnsTokenRequest
from dingtalk.api.rest.OapiEduGuardianListRequest import OapiEduGuardianListRequest
from dingtalk.api.rest.CorpHealthStepinfoListbyuseridRequest import CorpHealthStepinfoListbyuseridRequest
from dingtalk.api.rest.CorpSmartdeviceGetfaceRequest import CorpSmartdeviceGetfaceRequest
from dingtalk.api.rest.OapiWorkspaceTasklistHiddenCancelRequest import OapiWorkspaceTasklistHiddenCancelRequest
from dingtalk.api.rest.OapiProcessBizsuiteGetRequest import OapiProcessBizsuiteGetRequest
from dingtalk.api.rest.OapiMaterialArticleDeleteRequest import OapiMaterialArticleDeleteRequest
from dingtalk.api.rest.OapiAttendanceGroupMemberusersListRequest import OapiAttendanceGroupMemberusersListRequest
from dingtalk.api.rest.OapiAppstoreInternalOrderConsumeRequest import OapiAppstoreInternalOrderConsumeRequest
from dingtalk.api.rest.OapiMicroappCheckuidRequest import OapiMicroappCheckuidRequest
from dingtalk.api.rest.SmartworkBpmsProcessinstanceGetwithformRequest import SmartworkBpmsProcessinstanceGetwithformRequest
from dingtalk.api.rest.OapiCollectionInstanceGetRequest import OapiCollectionInstanceGetRequest
from dingtalk.api.rest.OapiPbpEventResultSyncRequest import OapiPbpEventResultSyncRequest
from dingtalk.api.rest.OapiDepartmentListRequest import OapiDepartmentListRequest
from dingtalk.api.rest.OapiIndustryDepartmentGetRequest import OapiIndustryDepartmentGetRequest
from dingtalk.api.rest.CorpDingReceiverstatusListRequest import CorpDingReceiverstatusListRequest
from dingtalk.api.rest.OapiSceneservicegroupGroupsetCreateRequest import OapiSceneservicegroupGroupsetCreateRequest
from dingtalk.api.rest.OapiProcessWorkrecordForwardCreateRequest import OapiProcessWorkrecordForwardCreateRequest
from dingtalk.api.rest.OapiCalendarV2EventCreateRequest import OapiCalendarV2EventCreateRequest
from dingtalk.api.rest.OapiRhinoHumanresEmployeeProductionteamListRequest import OapiRhinoHumanresEmployeeProductionteamListRequest
from dingtalk.api.rest.OapiWorkspaceTaskDeleteRequest import OapiWorkspaceTaskDeleteRequest
from dingtalk.api.rest.OapiCallbackFailrecordConfirmRequest import OapiCallbackFailrecordConfirmRequest
from dingtalk.api.rest.OapiV2DepartmentGetRequest import OapiV2DepartmentGetRequest
from dingtalk.api.rest.OapiSmartdeviceVisitorSendnotifyRequest import OapiSmartdeviceVisitorSendnotifyRequest
from dingtalk.api.rest.OapiAttendanceApproveDurationCalculateRequest import OapiAttendanceApproveDurationCalculateRequest
from dingtalk.api.rest.OapiEnterpriseMicroappUsedataStatRequest import OapiEnterpriseMicroappUsedataStatRequest
from dingtalk.api.rest.OapiCallBackGetCallBackFailedResultRequest import OapiCallBackGetCallBackFailedResultRequest
from dingtalk.api.rest.OapiImChatServicegroupQueryRequest import OapiImChatServicegroupQueryRequest
from dingtalk.api.rest.OapiCrmObjectdataCustomerUpdateRequest import OapiCrmObjectdataCustomerUpdateRequest
from dingtalk.api.rest.OapiAlitripBtripCostCenterDeleteRequest import OapiAlitripBtripCostCenterDeleteRequest
from dingtalk.api.rest.OapiAtsEvaluateJobmatchFinishRequest import OapiAtsEvaluateJobmatchFinishRequest
from dingtalk.api.rest.OapiKacOpenliveWhiteUsersBatchAddRequest import OapiKacOpenliveWhiteUsersBatchAddRequest
from dingtalk.api.rest.OapiCspaceAuthGenerateRequest import OapiCspaceAuthGenerateRequest
from dingtalk.api.rest.OapiEduCourseParticipantBatchaddRequest import OapiEduCourseParticipantBatchaddRequest
from dingtalk.api.rest.OapiImpaasUserAddprofileRequest import OapiImpaasUserAddprofileRequest
from dingtalk.api.rest.OapiUserGetbyunionidRequest import OapiUserGetbyunionidRequest
from dingtalk.api.rest.OapiCallRemoveuserlistRequest import OapiCallRemoveuserlistRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesScrapRequest import OapiRhinoMosExecClothesScrapRequest
from dingtalk.api.rest.OapiSmartdeviceRemovefaceRequest import OapiSmartdeviceRemovefaceRequest
from dingtalk.api.rest.OapiSmartdeviceFacegroupRemoveallRequest import OapiSmartdeviceFacegroupRemoveallRequest
from dingtalk.api.rest.OapiImpaasMessageGetmessagestatusRequest import OapiImpaasMessageGetmessagestatusRequest
from dingtalk.api.rest.OapiAlitripBtripInvoiceSettingRuleRequest import OapiAlitripBtripInvoiceSettingRuleRequest
from dingtalk.api.rest.OapiImpaasGroupModifyRequest import OapiImpaasGroupModifyRequest
from dingtalk.api.rest.OapiLiveGroupliveViewrecordRequest import OapiLiveGroupliveViewrecordRequest
from dingtalk.api.rest.OapiCollectionSchemaCreateRequest import OapiCollectionSchemaCreateRequest
from dingtalk.api.rest.OapiReportGetunreadcountRequest import OapiReportGetunreadcountRequest
from dingtalk.api.rest.OapiAtsJobBatchaddRequest import OapiAtsJobBatchaddRequest
from dingtalk.api.rest.OapiEduCardCreateRequest import OapiEduCardCreateRequest
from dingtalk.api.rest.CorpDingCreateRequest import CorpDingCreateRequest
from dingtalk.api.rest.OapiPbpInstanceDisableRequest import OapiPbpInstanceDisableRequest
from dingtalk.api.rest.OapiAttendanceGroupPositionsQueryRequest import OapiAttendanceGroupPositionsQueryRequest
from dingtalk.api.rest.OapiRhinoMosLayoutOperationdefsListsimpleRequest import OapiRhinoMosLayoutOperationdefsListsimpleRequest
from dingtalk.api.rest.OapiLiveGroupliveListbytimeRequest import OapiLiveGroupliveListbytimeRequest
from dingtalk.api.rest.OapiSnsSyncActivityRequest import OapiSnsSyncActivityRequest
from dingtalk.api.rest.OapiSmartworkHrmOrganizationDeptGetRequest import OapiSmartworkHrmOrganizationDeptGetRequest
from dingtalk.api.rest.OapiUserGetRequest import OapiUserGetRequest
from dingtalk.api.rest.OapiWorkspaceTaskDeletebyprojectRequest import OapiWorkspaceTaskDeletebyprojectRequest
from dingtalk.api.rest.OapiAtsStatisticsResumeListRequest import OapiAtsStatisticsResumeListRequest
from dingtalk.api.rest.OapiProjectPointAddRequest import OapiProjectPointAddRequest
from dingtalk.api.rest.OapiWorkspaceAuditlogListRequest import OapiWorkspaceAuditlogListRequest
from dingtalk.api.rest.OapiRetailSellerOrgCheckRequest import OapiRetailSellerOrgCheckRequest
from dingtalk.api.rest.OapiBipaasGenericRequest import OapiBipaasGenericRequest
from dingtalk.api.rest.OapiHrmEmployeeDelresumerecordRequest import OapiHrmEmployeeDelresumerecordRequest
from dingtalk.api.rest.OapiChatTransformRequest import OapiChatTransformRequest
from dingtalk.api.rest.OapiImChatScenegroupUpdateRequest import OapiImChatScenegroupUpdateRequest
from dingtalk.api.rest.OapiEduFeedSyncRequest import OapiEduFeedSyncRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesSizeCountRequest import OapiRhinoMosExecClothesSizeCountRequest
from dingtalk.api.rest.OapiSmartworkHrmOrganizationDeptUpdateRequest import OapiSmartworkHrmOrganizationDeptUpdateRequest
from dingtalk.api.rest.OapiProcessTemplateManageGetRequest import OapiProcessTemplateManageGetRequest
from dingtalk.api.rest.OapiEduHomeworkQueryRequest import OapiEduHomeworkQueryRequest
from dingtalk.api.rest.OapiAuthorizationRbacRoleCreateRequest import OapiAuthorizationRbacRoleCreateRequest
from dingtalk.api.rest.CorpDingTaskCreateRequest import CorpDingTaskCreateRequest
from dingtalk.api.rest.OapiRhinoMosExecTrackBindRequest import OapiRhinoMosExecTrackBindRequest
from dingtalk.api.rest.CorpUserPersonainfoGetRequest import CorpUserPersonainfoGetRequest
from dingtalk.api.rest.OapiEduSubjectListRequest import OapiEduSubjectListRequest
from dingtalk.api.rest.OapiCrmObjectdataCustomerQueryRequest import OapiCrmObjectdataCustomerQueryRequest
from dingtalk.api.rest.OapiRhinoMosSpaceDeviceCheckInRequest import OapiRhinoMosSpaceDeviceCheckInRequest
from dingtalk.api.rest.OapiWorkbenchShortcutDeleteRequest import OapiWorkbenchShortcutDeleteRequest
from dingtalk.api.rest.OapiRobotIntelligentMessageSendRequest import OapiRobotIntelligentMessageSendRequest
from dingtalk.api.rest.OapiImChatScencegroupFileDownloadurlGetRequest import OapiImChatScencegroupFileDownloadurlGetRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesFinishRequest import OapiRhinoMosExecClothesFinishRequest
from dingtalk.api.rest.OapiImpaasRelationDelRequest import OapiImpaasRelationDelRequest
from dingtalk.api.rest.OapiAiMtTranslateRequest import OapiAiMtTranslateRequest
from dingtalk.api.rest.OapiSmartdeviceBindCreateRequest import OapiSmartdeviceBindCreateRequest
from dingtalk.api.rest.OapiImpaasConversationUpdateentranceidRequest import OapiImpaasConversationUpdateentranceidRequest
from dingtalk.api.rest.OapiEduClassStudentinfoGetRequest import OapiEduClassStudentinfoGetRequest
from dingtalk.api.rest.OapiSmartdeviceBatcheventPostRequest import OapiSmartdeviceBatcheventPostRequest
from dingtalk.api.rest.OapiAtsMessageSystemaccountSendmessageRequest import OapiAtsMessageSystemaccountSendmessageRequest
from dingtalk.api.rest.OapiChatbotInstallRequest import OapiChatbotInstallRequest
from dingtalk.api.rest.OapiMessageCorpconversationAsyncsendbycodeRequest import OapiMessageCorpconversationAsyncsendbycodeRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeAttachmentUpdateRequest import OapiSmartworkHrmEmployeeAttachmentUpdateRequest
from dingtalk.api.rest.OapiCrmObjectmetaDescribeRequest import OapiCrmObjectmetaDescribeRequest
from dingtalk.api.rest.OapiOpenencryptHeartbeatRequest import OapiOpenencryptHeartbeatRequest
from dingtalk.api.rest.OapiAlitripBtripFlightOrderSearchRequest import OapiAlitripBtripFlightOrderSearchRequest
from dingtalk.api.rest.OapiConferencePublishRequest import OapiConferencePublishRequest
from dingtalk.api.rest.CorpChatbotInstallRequest import CorpChatbotInstallRequest
from dingtalk.api.rest.OapiImpaasConversaionChangegroupownerRequest import OapiImpaasConversaionChangegroupownerRequest
from dingtalk.api.rest.OapiImChatServicegroupCreateRequest import OapiImChatServicegroupCreateRequest
from dingtalk.api.rest.OapiMessageMassRecallRequest import OapiMessageMassRecallRequest
from dingtalk.api.rest.CorpBlazersRemovemappingRequest import CorpBlazersRemovemappingRequest
from dingtalk.api.rest.OapiUserSeniorSettingRequest import OapiUserSeniorSettingRequest
from dingtalk.api.rest.OapiAppstoreInternalRemindRequest import OapiAppstoreInternalRemindRequest
from dingtalk.api.rest.CorpChatbotUpdateorgbotRequest import CorpChatbotUpdateorgbotRequest
from dingtalk.api.rest.OapiMaterialArticleUpdateRequest import OapiMaterialArticleUpdateRequest
from dingtalk.api.rest.OapiProcessInstanceCancelRequest import OapiProcessInstanceCancelRequest
from dingtalk.api.rest.OapiMessageCorpconversationGetsendresultRequest import OapiMessageCorpconversationGetsendresultRequest
from dingtalk.api.rest.CorpDeptgroupSyncuserRequest import CorpDeptgroupSyncuserRequest
from dingtalk.api.rest.OapiCrmObjectdataCustomerCreateRequest import OapiCrmObjectdataCustomerCreateRequest
from dingtalk.api.rest.OapiSmartdeviceFacegroupMemberListRequest import OapiSmartdeviceFacegroupMemberListRequest
from dingtalk.api.rest.OapiEduHomeworkCreateRequest import OapiEduHomeworkCreateRequest
from dingtalk.api.rest.OapiSmartdeviceFacegroupGetRequest import OapiSmartdeviceFacegroupGetRequest
from dingtalk.api.rest.OapiWorkspaceProjectAssistantSendRequest import OapiWorkspaceProjectAssistantSendRequest
from dingtalk.api.rest.SmartworkBpmsProcessinstanceidListRequest import SmartworkBpmsProcessinstanceidListRequest
from dingtalk.api.rest.OapiMessageCorpconversationAsyncsendV2Request import OapiMessageCorpconversationAsyncsendV2Request
from dingtalk.api.rest.OapiRhinoMosExecPerformFinishRequest import OapiRhinoMosExecPerformFinishRequest
from dingtalk.api.rest.OapiAtsChannelAccountDeleteRequest import OapiAtsChannelAccountDeleteRequest
from dingtalk.api.rest.OapiProcessinstanceExecuteV2Request import OapiProcessinstanceExecuteV2Request
from dingtalk.api.rest.OapiEduCourseParticipantListRequest import OapiEduCourseParticipantListRequest
from dingtalk.api.rest.OapiPbpInstanceGroupMemberUpdateRequest import OapiPbpInstanceGroupMemberUpdateRequest
from dingtalk.api.rest.OapiMaterialArticleGetRequest import OapiMaterialArticleGetRequest
from dingtalk.api.rest.OapiCircleEnworkUpdateRequest import OapiCircleEnworkUpdateRequest
from dingtalk.api.rest.OapiAlitripBtripCostCenterQueryRequest import OapiAlitripBtripCostCenterQueryRequest
from dingtalk.api.rest.OapiEduUserBindSyncRequest import OapiEduUserBindSyncRequest
from dingtalk.api.rest.SmartworkAttendsGetsimplegroupsRequest import SmartworkAttendsGetsimplegroupsRequest
from dingtalk.api.rest.OapiEduFaceGetRequest import OapiEduFaceGetRequest
from dingtalk.api.rest.OapiRhinoMosExecClothesUnperformedFilterRequest import OapiRhinoMosExecClothesUnperformedFilterRequest
from dingtalk.api.rest.OapiProcessCopyRequest import OapiProcessCopyRequest
from dingtalk.api.rest.OapiMpdevBuildStatusGetRequest import OapiMpdevBuildStatusGetRequest
from dingtalk.api.rest.OapiAttendanceClassGetRequest import OapiAttendanceClassGetRequest
from dingtalk.api.rest.OapiCollectionFormStopRequest import OapiCollectionFormStopRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeListdimissionRequest import OapiSmartworkHrmEmployeeListdimissionRequest
from dingtalk.api.rest.OapiMaterialNewsDeleteRequest import OapiMaterialNewsDeleteRequest
from dingtalk.api.rest.OapiHealthStepinfoGetuserstatusRequest import OapiHealthStepinfoGetuserstatusRequest
from dingtalk.api.rest.OapiEduUserGetRequest import OapiEduUserGetRequest
from dingtalk.api.rest.OapiRhinoMosExecPerformConditionalStartRequest import OapiRhinoMosExecPerformConditionalStartRequest
from dingtalk.api.rest.OapiMessageCorpconversationRecallRequest import OapiMessageCorpconversationRecallRequest
from dingtalk.api.rest.OapiWikiDocListRequest import OapiWikiDocListRequest
from dingtalk.api.rest.CorpRoleSimplelistRequest import CorpRoleSimplelistRequest
from dingtalk.api.rest.OapiUserListidRequest import OapiUserListidRequest
from dingtalk.api.rest.OapiRoleAddRoleRequest import OapiRoleAddRoleRequest
from dingtalk.api.rest.OapiRhinoMosExecPerformBatchCreateRequest import OapiRhinoMosExecPerformBatchCreateRequest
from dingtalk.api.rest.OapiAttendanceGroupUsersAddRequest import OapiAttendanceGroupUsersAddRequest
from dingtalk.api.rest.OapiChatSubadminUpdateRequest import OapiChatSubadminUpdateRequest
from dingtalk.api.rest.OapiEduDeptListRequest import OapiEduDeptListRequest
from dingtalk.api.rest.OapiConferenceGetRequest import OapiConferenceGetRequest
from dingtalk.api.rest.OapiDdpaasObjectmetaDescribeRequest import OapiDdpaasObjectmetaDescribeRequest
from dingtalk.api.rest.OapiSmartworkHrmEmployeeDismissionUpdateRequest import OapiSmartworkHrmEmployeeDismissionUpdateRequest
from dingtalk.api.rest.OapiWorkspaceProjectMemberRemoveRequest import OapiWorkspaceProjectMemberRemoveRequest
from dingtalk.api.rest.OapiRetailUserBindqueryRequest import OapiRetailUserBindqueryRequest



'''
Created by auto_sdk on 2021.05.08
'''
from dingtalk.api.base import RestApi
class OapiDingpayRedenvelopeSendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.chat_id = None
		self.corp_biz_no = None
		self.ext_params = None
		self.greetings = None
		self.open_conversation_id = None
		self.pay_method = None
		self.pay_sign = None
		self.receiver_id = None
		self.sender_id = None
		self.theme_id = None
		self.total_amount = None
		self.type = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.dingpay.redenvelope.send'



'''
Created by auto_sdk on 2020.03.30
'''
from dingtalk.api.base import RestApi
class OapiImChatServicegroupMemberQueryRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.chat_id = None
		self.include_owner = None
		self.page_num = None
		self.page_size = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.servicegroup.member.query'



'''
Created by auto_sdk on 2022.09.13
'''
from dingtalk.api.base import RestApi
class OapiFinanceLoanNotifyCreditRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.amount = None
		self.available_amount = None
		self.change_amount = None
		self.complete_time = None
		self.credit_no = None
		self.credit_type = None
		self.daily_interest_rate = None
		self.extension = None
		self.id_card_no = None
		self.next_apply_day = None
		self.open_channel_name = None
		self.open_product_code = None
		self.open_product_name = None
		self.open_product_type = None
		self.refuse_code = None
		self.refuse_reason = None
		self.status = None
		self.submit_time = None
		self.user_mobile = None
		self.year_interest_rate = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.finance.loan.notify.credit'



'''
Created by auto_sdk on 2020.12.07
'''
from dingtalk.api.base import RestApi
class OapiUserSeniorSettingRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.open = None
		self.permit_staffIds = None
		self.protect_scenes = None
		self.senior_staffId = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.user.senior.setting'



'''
Created by auto_sdk on 2020.01.06
'''
from dingtalk.api.base import RestApi
class OapiMcsConferenceCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_key = None
		self.is_push_record = None
		self.preference_region = None
		self.room_valid_time = None
		self.title = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.mcs.conference.create'



'''
Created by auto_sdk on 2021.01.08
'''
from dingtalk.api.base import RestApi
class OapiSmartworkHrmEmployeeOnjoblistQueryRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.cursor = None
		self.search_param = None
		self.size = None
		self.status_list = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.smartwork.hrm.employee.onjoblist.query'



'''
Created by auto_sdk on 2019.09.19
'''
from dingtalk.api.base import RestApi
class OapiAttendanceApproveScheduleSwitchRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.apply_shift_id = None
		self.apply_userid = None
		self.approve_id = None
		self.reback_apply_shift_id = None
		self.reback_date = None
		self.reback_target_shift_id = None
		self.switch_date = None
		self.target_shift_id = None
		self.target_userid = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.approve.schedule.switch'



'''
Created by auto_sdk on 2021.09.27
'''
from dingtalk.api.base import RestApi
class OapiAttendanceVacationTypeCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_type = None
		self.extras = None
		self.freedom_leave = None
		self.hours_in_per_day = None
		self.leave_certificate = None
		self.leave_hour_ceil = None
		self.leave_name = None
		self.leave_time_ceil = None
		self.leave_time_ceil_min_unit = None
		self.leave_view_unit = None
		self.max_leave_time = None
		self.min_leave_hour = None
		self.natural_day_leave = None
		self.op_userid = None
		self.paid_leave = None
		self.submit_time_rule = None
		self.visibility_rules = None
		self.when_can_leave = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.attendance.vacation.type.create'



'''
Created by auto_sdk on 2020.11.05
'''
from dingtalk.api.base import RestApi
class OapiConnectorOpenRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.connector_id = None
		self.corp_id = None
		self.creator_userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.connector.open'



'''
Created by auto_sdk on 2020.05.29
'''
from dingtalk.api.base import RestApi
class OapiImChatControlgroupCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.authority_type = None
		self.group_type = None
		self.group_uniq_id = None
		self.member_userids = None
		self.owner_userid = None
		self.title = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.controlgroup.create'



'''
Created by auto_sdk on 2020.12.23
'''
from dingtalk.api.base import RestApi
class OapiWorkspaceTasklistAddbyprojectRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.microapp_agent_id = None
		self.operator_userid = None
		self.project_id = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.workspace.tasklist.addbyproject'



'''
Created by auto_sdk on 2020.11.16
'''
from dingtalk.api.base import RestApi
class OapiCrmObjectdataContactListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.current_operator_userid = None
		self.data_id_list = None
		self.provider_corpid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.crm.objectdata.contact.list'



'''
Created by auto_sdk on 2022.03.24
'''
from dingtalk.api.base import RestApi
class OapiWorkrecordAddRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_id = None
		self.create_time = None
		self.formItemList = None
		self.originator_user_id = None
		self.pcUrl = None
		self.pc_open_type = None
		self.source_name = None
		self.title = None
		self.url = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.workrecord.add'



'''
Created by auto_sdk on 2020.09.16
'''
from dingtalk.api.base import RestApi
class OapiReportTemplateGetbynameRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.template_name = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.report.template.getbyname'



'''
Created by auto_sdk on 2019.07.01
'''
from dingtalk.api.base import RestApi
class OapiDingpayOrderMarkotherpayRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.apply_pay_operator_userid = None
		self.extension = None
		self.order_nos = None
		self.pay_channel_payer_real_uid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.dingpay.order.markotherpay'



'''
Created by auto_sdk on 2020.08.04
'''
from dingtalk.api.base import RestApi
class OapiAtsJobDeliverAddRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_code = None
		self.deliver_channel = None
		self.deliver_msg = None
		self.deliver_outer_id = None
		self.deliver_status = None
		self.job_id = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.ats.job.deliver.add'



'''
Created by auto_sdk on 2022.09.13
'''
from dingtalk.api.base import RestApi
class OapiFinanceLoanNotifyLendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.amount_update_time = None
		self.available_limit = None
		self.bank_name = None
		self.bankcard_no = None
		self.bill_date = None
		self.bill_info_list = None
		self.credit_amount = None
		self.daily_interest_rate = None
		self.discounts_id = None
		self.fail_reason = None
		self.fail_reason_to_user = None
		self.first_bill_date = None
		self.first_repay_date = None
		self.id_card_no = None
		self.last_repay_date = None
		self.loan_amount = None
		self.loan_effective_time = None
		self.loan_end_time = None
		self.loan_order_flow_no = None
		self.loan_order_no = None
		self.loan_submit_time = None
		self.loan_txn_time = None
		self.loan_usage = None
		self.open_channel_name = None
		self.open_product_code = None
		self.open_product_name = None
		self.open_product_type = None
		self.paid_interest = None
		self.paid_penalty = None
		self.paid_principal = None
		self.paid_total_amount = None
		self.payable_interest = None
		self.payable_penalty = None
		self.payable_principal = None
		self.payable_total_amount = None
		self.reduction_total_amount = None
		self.repay_date = None
		self.repay_type = None
		self.status = None
		self.total_term = None
		self.user_mobile = None
		self.year_loan_interest_rate = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.finance.loan.notify.lend'



'''
Created by auto_sdk on 2019.07.03
'''
from dingtalk.api.base import RestApi
class CorpDingReceiverstatusListRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.confirmed_status = None
		self.ding_id = None
		self.page_no = None
		self.page_size = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.corp.ding.receiverstatus.list'



'''
Created by auto_sdk on 2020.04.29
'''
from dingtalk.api.base import RestApi
class OapiEduHomeworkUpdateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.biz_code = None
		self.hw_id = None
		self.identifier = None
		self.status = None
		self.teacher_userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.homework.update'



'''
Created by auto_sdk on 2021.04.01
'''
from dingtalk.api.base import RestApi
class OapiDingtalkImpaasMessageCrossdomainSendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.crossdomain_message_send_model = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.dingtalk.impaas.message.crossdomain.send'



'''
Created by auto_sdk on 2020.12.22
'''
from dingtalk.api.base import RestApi
class OapiEduGroupMsgSendRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.agent_id = None
		self.biz_id = None
		self.class_id = None
		self.image_url = None
		self.receive_userid_list = None
		self.replace = None
		self.template_code = None
		self.userid = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.edu.group.msg.send'



'''
Created by auto_sdk on 2021.10.12
'''
from dingtalk.api.base import RestApi
class OapiAppstoreOrdersInquiryRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.corpid = None
		self.cyc_num = None
		self.cyc_unit = None
		self.goods_code = None
		self.item_code = None
		self.mobile = None
		self.quantity = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.appstore.orders.inquiry'



'''
Created by auto_sdk on 2019.08.22
'''
from dingtalk.api.base import RestApi
class OapiImChatServicegroupCreateRequest(RestApi):
	def __init__(self,url=None):
		RestApi.__init__(self,url)
		self.group_uniq_id = None
		self.org_inner_group = None
		self.owner_userid = None
		self.title = None

	def getHttpMethod(self):
		return 'POST'

	def getapiname(self):
		return 'dingtalk.oapi.im.chat.servicegroup.create'
